Crate otter_api_tests[−][src]
Re-exports
pub use imports::*; |
Modules
| authproofs | |
| base_misc | |
| btree_map | A map based on a B-Tree. |
| btree_set | A set based on a B-Tree. |
| cleanup_notify | |
| cmp | Functionality for ordering and comparison. |
| env | Inspection and manipulation of the process’s environment. |
| flexi_logger | A flexible and easy-to-use logger that writes logs to stderr and/or to files or other output streams. |
| fmt | Utilities for formatting and printing |
| fs | Filesystem manipulation operations. |
| geometry | |
| hash_map | A hash map implemented with quadratic probing and SIMD lookup. |
| imports | |
| io | Traits, helpers, and type definitions for core I/O functionality. |
| iter | Composable external iteration. |
| loaded_acl | |
| mpsc | Multi-producer, single-consumer FIFO queue communication primitives. |
| nwtemplates | |
| organise | |
| serde_json | Serde JSON |
| shapelib | |
| str | Unicode string slices. |
| thiserror | |
| thread | Native threads. |
| time | Temporal quantification. |
| unistd | Safe wrappers around functions found in libc “unistd.h” header |
| unix | Unix Platform-specific extensions to |
| zcoord |
Macros
| Debug | Derive macro generating an impl of the trait |
| Hash | Derive macro generating an impl of the trait |
| anyhow | Construct an ad-hoc error from a string or existing non- |
| dbgc | |
| debug | Logs a message at the debug level. |
| define_index_type | Generate the boilerplate for a newtyped index struct, for use with
|
| delegate | |
| deref_to_field | |
| deref_to_field_mut | |
| display_as_debug | |
| display_consequential_impls | |
| ensure | Return early with an error if a condition is not satisfied. |
| ensure_eq | |
| env | Inspects an environment variable at compile time. |
| error | Logs a message at the error level. |
| error_from_losedetails | |
| hformat | |
| hformat_as_display | |
| hwrite | |
| if_chain | Macro for writing nested |
| if_let | |
| impl_downcast | Adds downcasting support to traits that extend |
| impl_for_slotmap_key | |
| index_vec | A macro equivalent to the stdlib’s |
| info | Logs a message at the info level. |
| izip | Create an iterator running multiple iterators in lockstep. |
| json | Construct a |
| lazy_static | |
| log | The standard logging macro. |
| log_enabled | Determines if a message logged at the specified level in that module will be logged. |
| matches_doesnot | |
| test | |
| throw | Throw an error. |
| trace | Logs a message at the trace level. |
| trace_dbg | |
| usual_wanted_tests | |
| visible_slotmap_key | |
| want | |
| want_failed_internal | |
| want_let | |
| wantok | |
| wants | |
| warn | Logs a message at the warn level. |
Structs
| AbbrevPresentationLayout | |
| AccessRecord | Record of acess for a player. Newtype prevents mutable access without invalidating old tokens and permissions check. |
| AccessTokenInfo | |
| AccessTokenReport | |
| AccountId | |
| AccountName | |
| AccountNotFound | |
| AccountRecord | |
| Accounts | |
| AccountsGuard | |
| Acl | |
| AclEntry | |
| Alphanumeric | Sample a |
| ApiPieceOpArgs | |
| Arc | A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’. |
| ArrayVec | A vector with a fixed capacity. |
| Authorisation | |
| BTreeMap | A map based on a B-Tree. |
| BTreeSet | A set based on a B-Tree. |
| BufReader | The |
| BufWriter | Wraps a writer and buffers its output. |
| Child | Representation of a running or exited child process. |
| CircleShape | |
| Client | |
| ClientId | |
| ClientSequence | |
| ColourSpec | |
| Command | A process builder, providing fine-grained control over how a new process should be spawned. |
| CommittedLogEntry | |
| CompassAngle | 0 = unrotated, +ve is anticlockwise, units of 45deg |
| Condvar | A Condition Variable |
| CoordinateOverflow | |
| Data | |
| DataLoadPlayer | |
| DebugReader | |
| DenseSlotMap | Dense slot map, storage with stable unique keys. |
| DirSubst | |
| Duration | A |
| EffectiveACL | |
| EnumMap | An enum mapping. |
| ExecuteGameChangeUpdates | |
| ExitStatusError | |
| ExtendedSubst | |
| FaceId | |
| FakeRngSpec | |
| File | A reference to an open file on the filesystem. |
| FixedToken | |
| FooParseError | |
| Formatter | Configuration for formatting. |
| GLOBAL | |
| GPiece | |
| GPieces | |
| GPlayer | |
| GameBeingDestroyed | |
| GameOccults | |
| GameSpec | |
| GameState | |
| Generation | |
| GenericSimpleShape | |
| Global | |
| GoodItemName | |
| HashMap | A hash map implemented with quadratic probing and SIMD lookup. |
| HashSet | A hash set implemented as a |
| Html | |
| HtmlLit | |
| HtmlStr | |
| IOccults | |
| IPiece | |
| IPieceTraitObj | |
| IPieces | |
| IPlayer | |
| IndexSlice | A slice that only accepts indices of a specific type. Note that the intended
usage is as |
| IndexVec | A Vec that only accepts indices of a specific type. |
| Instance | |
| Instance | |
| InstanceAccessDetails | |
| InstanceContainer | |
| InstanceGuard | |
| InstanceName | |
| InstanceRef | |
| InstanceWeakRef | |
| Instant | A measurement of a monotonically nondecreasing clock.
Opaque and useful only with |
| InternalLogicError | |
| IsHtmlFormatted | |
| JsonString | |
| LinksTable | |
| LoadedAcl | |
| LogEntry | |
| LogSpecification | Immutable struct that defines which loglines are to be written, based on the module, the log level, and the text. |
| MgmtChannel | |
| MgmtChannelForGame | |
| ModifyingPieces | |
| NascentOccultation | |
| NonZeroUsize | An integer that is known not to equal zero. |
| Notch | |
| Notches | |
| OccId | |
| OccultIlkData | |
| OccultIlkId | |
| OccultIlkName | |
| OccultIlkOwningId | Does not |
| OccultIlks | |
| OccultView | |
| Occultation | |
| OccultationViews | |
| OcculterRotationChecked | |
| OldNew | |
| Opts | |
| OrderedFloat | A wrapper around Floats providing an implementation of Ord and Hash. |
| OsStr | Borrowed reference to an OS string (see |
| OtterPauseable | |
| OtterPaused | |
| OwnerOccultationView | |
| PathBuf | An owned, mutable path (akin to |
| PerPlayerIdMap | |
| PermSet | |
| PhantomData | Zero-sized type used to mark things that “act like” they own a |
| PieceAliases | |
| PieceId | |
| PieceLabelLoaded | |
| PieceOccult | |
| PieceRenderInstructions | |
| PieceSpecLoaded | |
| PieceUpdate | |
| PiecesSpec | |
| PlayerAccessUnset | |
| PlayerId | |
| PlayerNotFound | |
| PlayerRecord | |
| PlayerUpdates | |
| PlayerUpdatesBuildContext | |
| PosC | |
| PrepareUpdatesBuffer | |
| PreparedPieceImage | |
| PreparedPieceState | |
| PreparedPieceUpdateGeneral | |
| PreparedUpdate | |
| PreparedUpdateEntry_Image | |
| PreparedUpdateEntry_Piece | |
| PrivateCaller | |
| RawToken | |
| RawTokenVal | |
| RectC | |
| RectShape | |
| RefCell | A mutable memory location with dynamically checked borrow rules |
| RefMut | A wrapper type for a mutably borrowed value from a |
| Regex | A compiled regular expression for matching Unicode strings. |
| RngWrap | |
| ServerConfig | |
| ServerConfigSpec | |
| SetupCore | |
| ShowUnocculted | |
| SimpleCommon | |
| SparseSecondaryMap | Sparse secondary map, associate data with previously stored elements in a slot map. |
| StableIndexVecDeque | Double-ended queue with stable indices |
| StaticUserIter | |
| StaticUserSetup | |
| Stdio | Describes what to do with a standard I/O stream for a child process when
passed to the |
| Subst | |
| TableSpec | |
| Thunk | |
| TimeSpec | |
| Timestamp | |
| Timezone | |
| ToRecalculate | |
| TokenByEmail | |
| TokenDeliveryError | |
| TokenRegistry | |
| TokenRevelationKey | |
| TokenRevelationValue | |
| TrackWantedTests | |
| TransmitUpdate | |
| TryFromIntError | The error type returned when a checked integral type conversion fails. |
| Uid | User identifier |
| Unauthorised | |
| UniformOccultationView | |
| UniqueGenGen | |
| UnixStream | A Unix stream socket. |
| UnsupportedColourSpec | |
| UoDescription | |
| Url | A parsed URL record. |
| UrlOnStdout | |
| UrlSpec | |
| VecDeque | A double-ended queue implemented with a growable ring buffer. |
| VisibleAngleTransform | |
| VisiblePieceId | |
| WantedTestsOpt | |
| WholeServerConfig | |
| Wrapping | Provides intentionally-wrapped arithmetic on |
| ZCoord | |
| ZLevel |
Enums
Constants
Traits
| AccessId | |
| AccountNameOrId | |
| Any | A trait to emulate dynamic typing. |
| Borrow | A trait for borrowing data. |
| Bounded | Numbers which have upper and lower bounds |
| BufRead | A |
| ById | |
| ClampTable | |
| CommandExt | Unix-specific extensions to the |
| Context | Provides the |
| Debug |
|
| Deref | Used for immutable dereferencing operations, like |
| DerefMut | Used for mutable dereferencing operations, like in |
| Deserialize | A data structure that can be deserialized from any data format supported by Serde. |
| DeserializeOwned | A data structure that can be deserialized without borrowing any data from the deserializer. |
| Deserializer | A data format that can deserialize any data structure supported by Serde. |
| Display | Format trait for an empty format, |
| Downcast | Supports conversion to |
| DynCastExt | Simplifies the use of the |
| EmptyType | |
| Enum | Enum mapping type |
| EnumProperty | EnumProperty is a trait that makes it possible to store additional information
with enum variants. This trait is designed to be used with the macro of the same
name in the |
| Error |
|
| FileExt | Extension trait for |
| FromPrimitive | A generic trait for converting a number to a value. |
| FromStr | Parse a value from a string |
| Hash | A hashable type. |
| Hasher | A trait for hashing an arbitrary stream of bytes. |
| HtmlFormat | |
| HtmlFormatRef | |
| HtmlIteratorExt | |
| IdForById | |
| Index | Used for indexing operations ( |
| IndexMut | Used for indexing operations ( |
| IntoEnumIterator | This trait designates that an |
| IntoRawFd | A trait to express the ability to consume an object and acquire ownership of its raw file descriptor. |
| IoTryClone | |
| IteratorExt | |
| Itertools | An |
| JsonLen | |
| KeyDataExt | Extension trait for |
| LocalFileExt | |
| MetadataExt | OS-specific extensions to |
| MgmtChannelExt | |
| NumCast | An interface for casting between machine scalars. |
| OccultationViewDef | |
| OccultedPieceTrait | |
| Optionpiece_specsPieceLabelExt | |
| OrdExt | |
| OsStrExt | Platform-specific extensions to |
| OutlineTrait | |
| PieceSpec | |
| PieceTrait | |
| PieceXData | |
| PieceXDataStateExt | |
| PlayerAccessSpec | |
| PosPromote | |
| Read | The |
| ResultTEExt | |
| ResultVoidErrExt | Extensions to |
| ResultVoidExt | Extensions to |
| Rng | An automatically-implemented extension trait on |
| Seek | The |
| Serialize | A data structure that can be serialized into any data format supported by Serde. |
| SerializeTuple | Returned from |
| Serializer | A data format that can serialize any data structure supported by Serde. |
| SimplePieceSpec | |
| SliceRandom | Extension trait on slices, providing random mutation and sampling methods. |
| SlotmapSparseSecondaryEntryExt | |
| SplitAtDelim | |
| StructOpt | A struct that is converted from command line arguments. |
| Substitutor | |
| ToPrimitive | A generic trait for converting a value to a number. |
| TryFrom | Simple and safe type conversions that may fail in a controlled
way under some circumstances. It is the reciprocal of |
| TryInto | An attempted conversion that consumes |
| TupleOfLinkKindRefstrExt | |
| VecPieceIdPieceUpdateOpsExt | |
| Write | A trait for objects which are byte-oriented sinks. |
| _ | A trait for writing or formatting into Unicode-accepting buffers or streams. |
| _ | This trait defines a number of combinator-style methods for use with |
| _ | Key used to access stored values in a slot map. |
Functions
| client_periodic_expiry | |
| clock_gettime | Get the time of the specified clock, (see clock_gettime(2)). |
| config | |
| consistency_check | |
| create_occultation | |
| dbgc_helper | |
| default | |
| exit | Terminates the current process with the specified exit code. |
| fork_something_which_prints | |
| game_flush_task | |
| games_lock | |
| internal_error_bydebug | |
| internal_logic_error | |
| keydata_extract | Underlying extraction function. Fails rather than panicing. |
| load_accounts | |
| load_games | |
| log_config | |
| log_did_to_piece | |
| log_did_to_piece_whoby | |
| logs_periodic_expiry | |
| lookup_token | |
| max | Compares and returns the maximum of two values. |
| min | Compares and returns the minimum of two values. |
| percent_decode_str | Percent-decode the given string. |
| piece_pri | None => do not render at all |
| player_dasharray | |
| player_num_dasharray | |
| prepare_game | |
| prepare_gameserver | |
| prepare_tmpdir | |
| process_all_players_for_account | |
| raw_angle_transform | |
| recalculate_occultation_piece | |
| record_token | |
| reinvoke_via_bwrap | |
| remove_occultation | |
| repeat_with | Creates a new iterator that repeats elements of type |
| setup_core | |
| sleep | Puts the current thread to sleep for at least the specified amount of time. |
| slotkey_parse | |
| slotkey_write | |
| space_rect_attrs | |
| space_table_attrs | |
| svg_circle_path | |
| svg_rectangle_path | |
| svg_rescale_path | |
| synch_logentry | |
| thread_rng | Retrieve the lazily-initialized thread-local random number generator,
seeded by the system. Intended to be used in method chaining style,
e.g. |
| timestring_abbreviate | |
| toml_merge | |
| unreachable | A safe version of |
| utf8_percent_encode | Percent-encode the UTF-8 encoding of the given string. |
| vpiece_decode | |
| zip_eq | Iterate |
Type Definitions
Attribute Macros
| dyn_upcast | |
| enum_dispatch | Annotating a trait or enum definition with an |
| ext | See crate docs for more info. |
| throws |
Derive Macros
| Deserialize | |
| DeserializeFromStr | Deserialize value by using it’s |
| Enum | Procedural derive generating |
| EnumIter | Creates a new type that iterates of the variants of an enum. |
| EnumProperty | Add custom properties to enum variants. |
| EnumString | Converts strings to enum variants based on their name. |
| Error | |
| FromPrimitive | Derives |
| IntoStaticStr | Implements |
| Serialize | |
| SerializeDisplay | Serialize value by using it’s |
| StructOpt | Generates the |