Struct otter_api_tests::btree_map::OccupiedEntry 1.0.0[−][src]
pub struct OccupiedEntry<'a, K, V> where
K: 'a,
V: 'a, { /* fields omitted */ }A view into an occupied entry in a BTreeMap.
It is part of the Entry enum.
Implementations
impl<'a, K, V> OccupiedEntry<'a, K, V> where
K: Ord, [src]
K: Ord,
pub fn key(&self) -> &KⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;1.10.0[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Gets a reference to the key in the entry.
Examples
use std::collections::BTreeMap; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); assert_eq!(map.entry("poneyland").key(), &"poneyland");
pub fn remove_entry(self) -> (K, V)1.12.0[src]
Take ownership of the key and value from the map.
Examples
use std::collections::BTreeMap; use std::collections::btree_map::Entry; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); if let Entry::Occupied(o) = map.entry("poneyland") { // We delete the entry from the map. o.remove_entry(); } // If now try to get the value, it will panic: // println!("{}", map["poneyland"]);
pub fn get(&self) -> &VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Gets a reference to the value in the entry.
Examples
use std::collections::BTreeMap; use std::collections::btree_map::Entry; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); if let Entry::Occupied(o) = map.entry("poneyland") { assert_eq!(o.get(), &12); }
pub fn get_mut(&mut self) -> &mut VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Gets a mutable reference to the value in the entry.
If you need a reference to the OccupiedEntry that may outlive the
destruction of the Entry value, see into_mut.
Examples
use std::collections::BTreeMap; use std::collections::btree_map::Entry; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); assert_eq!(map["poneyland"], 12); if let Entry::Occupied(mut o) = map.entry("poneyland") { *o.get_mut() += 10; assert_eq!(*o.get(), 22); // We can use the same Entry multiple times. *o.get_mut() += 2; } assert_eq!(map["poneyland"], 24);
pub fn into_mut(self) -> &'a mut VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Converts the entry into a mutable reference to its value.
If you need multiple references to the OccupiedEntry, see get_mut.
Examples
use std::collections::BTreeMap; use std::collections::btree_map::Entry; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); assert_eq!(map["poneyland"], 12); if let Entry::Occupied(o) = map.entry("poneyland") { *o.into_mut() += 10; } assert_eq!(map["poneyland"], 22);
pub fn insert(&mut self, value: V) -> V[src]
Sets the value of the entry with the OccupiedEntry’s key,
and returns the entry’s old value.
Examples
use std::collections::BTreeMap; use std::collections::btree_map::Entry; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); if let Entry::Occupied(mut o) = map.entry("poneyland") { assert_eq!(o.insert(15), 12); } assert_eq!(map["poneyland"], 15);
pub fn remove(self) -> V[src]
Takes the value of the entry out of the map, and returns it.
Examples
use std::collections::BTreeMap; use std::collections::btree_map::Entry; let mut map: BTreeMap<&str, usize> = BTreeMap::new(); map.entry("poneyland").or_insert(12); if let Entry::Occupied(o) = map.entry("poneyland") { assert_eq!(o.remove(), 12); } // If we try to get "poneyland"'s value, it'll panic: // println!("{}", map["poneyland"]);