Enum otter_api_tests::env::VarError 1.0.0[−][src]
pub enum VarError {
NotPresent,
NotUnicode(OsString),
}The error type for operations interacting with environment variables.
Possibly returned from env::var().
Variants
The specified environment variable was not present in the current process’s environment.
NotUnicode(OsString)The specified environment variable was found, but it did not contain valid unicode data. The found data is returned as a payload of this variant.