Enum otter_api_tests::flexi_logger::AdaptiveFormat [−]
pub enum AdaptiveFormat {
Default,
Detailed,
Opt,
WithThread,
Custom(fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>, fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>),
}Specifies the FormatFunction and decides if coloring should be used.
Is used in
Logger::adaptive_format_for_stderr and
Logger::adaptive_format_for_stdout.
The coloring format functions are used if the output channel is a tty.
Only available with feature atty.
Variants
Chooses between default_format
and colored_default_format.
Only available with feature colors.
Chooses between detailed_format
and colored_detailed_format.
Only available with feature colors.
Chooses between opt_format
and colored_opt_format.
Only available with feature colors.
Chooses between with_thread
and colored_with_thread.
Only available with feature colors.
Custom(fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>, fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>)Chooses between the first format function (which is supposed to be uncolored) and the second (which is supposed to be colored).
Allows providing own format functions, with freely choosable coloring technique, and making use of the tty detection.