Enum otter_api_tests::flexi_logger::Age[]

pub enum Age {
    Day,
    Hour,
    Minute,
    Second,
}

The age after which a log file rotation will be triggered, when Criterion::Age is chosen.

Variants

Day

Rotate the log file when the local clock has started a new day since the current file had been created.

Hour

Rotate the log file when the local clock has started a new hour since the current file had been created.

Minute

Rotate the log file when the local clock has started a new minute since the current file had been created.

Second

Rotate the log file when the local clock has started a new second since the current file had been created.