Enum otter_api_tests::flexi_logger::Naming[]

pub enum Naming {
    Timestamps,
    Numbers,
}

The naming convention for rotated log files.

With file rotation, the logs are written to a file with infix _rCURRENT. When rotation happens, the CURRENT log file will be renamed to a file with another infix of the form "_r...". Naming defines which other infix will be used.

Used in Logger::rotate.

Variants

Timestamps

File rotation rotates to files with a timestamp-infix, like "r2020-01-27_14-41-08".

Numbers

File rotation rotates to files with a number-infix.