Struct otter_api_tests::flexi_logger::LogSpecBuilder[]

pub struct LogSpecBuilder { /* fields omitted */ }

Builder for LogSpecification.

Example

Use the reconfigurability feature and build the log spec programmatically.

use flexi_logger::{Logger, LogSpecBuilder};
use log::LevelFilter;

fn main() {
    // Build the initial log specification
    let mut builder = LogSpecBuilder::new();  // default is LevelFilter::Off
    builder.default(LevelFilter::Info);
    builder.module("karl", LevelFilter::Debug);

    // Initialize Logger, keep builder alive
    let mut logger_reconf_handle = Logger::with(builder.build())
        // your logger configuration goes here, as usual
        .start()
        .unwrap_or_else(|e| panic!("Logger initialization failed with {}", e));

    // ...

    // Modify builder and update the logger
    builder.default(LevelFilter::Error);
    builder.remove("karl");
    builder.module("emma", LevelFilter::Trace);

    logger_reconf_handle.set_new_spec(builder.build());

    // ...
}

Implementations

impl LogSpecBuilder

#[must_use]
pub fn new() -> LogSpecBuilder

Creates a LogSpecBuilder with all logging turned off.

#[must_use]
pub fn from_module_filters(module_filters: &[ModuleFilter]) -> LogSpecBuilder

Creates a LogSpecBuilder from given module filters.

pub fn default(&mut self, lf: LevelFilter) -> &mut LogSpecBuilder

Adds a default log level filter, or updates the default log level filter.

pub fn module<M>(
    &mut self,
    module_name: M,
    lf: LevelFilter
) -> &mut LogSpecBuilder where
    M: AsRef<str>, 

Adds a log level filter, or updates the log level filter, for a module.

pub fn remove<M>(&mut self, module_name: M) -> &mut LogSpecBuilder where
    M: AsRef<str>, 

Adds a log level filter, or updates the log level filter, for a module.

pub fn insert_modules_from(
    &mut self,
    other: LogSpecification
) -> &mut LogSpecBuilder

Adds log level filters from a LogSpecification.

#[must_use]
pub fn finalize(self) -> LogSpecification

Creates a log specification without text filter.

pub fn finalize_with_textfilter(self, tf: Regex) -> LogSpecification

Creates a log specification with text filter.

This method is only avaible with feature textfilter, which is a default feature.

#[must_use]
pub fn build(&self) -> LogSpecification

Creates a log specification without being consumed.

pub fn build_with_textfilter(&self, tf: Option<Regex>) -> LogSpecification

Creates a log specification without being consumed, optionally with a text filter.

This method is only avaible with feature textfilter, which is a default feature.