Struct otter_api_tests::flexi_logger::ModuleFilter [−]
pub struct ModuleFilter {
pub module_name: Option<String>,
pub level_filter: LevelFilter,
}Defines which loglevel filter to use for the specified module.
A ModuleFilter, whose module_name is not set, describes the default loglevel filter.
Fields
module_name: Option<String>The module name.
level_filter: LevelFilterThe level filter.