Struct otter_api_tests::fmt::Arguments 1.0.0[−][src]
pub struct Arguments<'a> { /* fields omitted */ }This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.
The format_args! macro will safely create an instance of this structure.
The macro validates the format string at compile-time so usage of the
write() and format() functions can be safely performed.
You can use the Arguments<'a> that format_args! returns in Debug
and Display contexts as seen below. The example also shows that Debug
and Display format to the same thing: the interpolated format string
in format_args!.
let debug = format!("{:?}", format_args!("{} foo {:?}", 1, 2)); let display = format!("{}", format_args!("{} foo {:?}", 1, 2)); assert_eq!("1 foo 2", display); assert_eq!(display, debug);
Implementations
impl<'a> Arguments<'a>[src]
pub fn as_str(&self) -> Option<&'static str>1.52.0[src]
Get the formatted string, if it has no arguments to be formatted.
This can be used to avoid allocations in the most trivial case.
Examples
use std::fmt::Arguments; fn write_str(_: &str) { /* ... */ } fn write_fmt(args: &Arguments) { if let Some(s) = args.as_str() { write_str(s) } else { write_str(&args.to_string()); } }
assert_eq!(format_args!("hello").as_str(), Some("hello")); assert_eq!(format_args!("").as_str(), Some("")); assert_eq!(format_args!("{}", 1).as_str(), None);