Enum otter_api_tests::hash_map::Entry 1.0.0[−][src]
pub enum Entry<'a, K, V> where
K: 'a,
V: 'a, { Occupied(OccupiedEntry<'a, K, V>), Vacant(VacantEntry<'a, K, V>), }
A view into a single entry in a map, which may either be vacant or occupied.
Variants
Occupied(OccupiedEntry<'a, K, V>)An occupied entry.
Vacant(VacantEntry<'a, K, V>)A vacant entry.
Implementations
impl<'a, K, V> Entry<'a, K, V>[src]
pub fn or_insert(self, default: V) -> &'a mut VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); map.entry("poneyland").or_insert(3); assert_eq!(map["poneyland"], 3); *map.entry("poneyland").or_insert(10) *= 2; assert_eq!(map["poneyland"], 6);
pub fn or_insert_with<F>(self, default: F) -> &'a mut VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output; where
F: FnOnce() -> V, [src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;F: FnOnce() -> V,
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
use std::collections::HashMap; let mut map: HashMap<&str, String> = HashMap::new(); let s = "hoho".to_string(); map.entry("poneyland").or_insert_with(|| s); assert_eq!(map["poneyland"], "hoho".to_string());
pub fn or_insert_with_key<F>(self, default: F) -> &'a mut VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output; where
F: FnOnce(&K) -> V, 1.50.0[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;F: FnOnce(&K) -> V,
Ensures a value is in the entry by inserting, if empty, the result of the default function.
This method allows for generating key-derived values for insertion by providing the default
function a reference to the key that was moved during the .entry(key) method call.
The reference to the moved key is provided so that cloning or copying the key is
unnecessary, unlike with .or_insert_with(|| ... ).
Examples
use std::collections::HashMap; let mut map: HashMap<&str, usize> = HashMap::new(); map.entry("poneyland").or_insert_with_key(|key| key.chars().count()); assert_eq!(map["poneyland"], 9);
pub fn key(&self) -> &KⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;1.10.0[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Returns a reference to this entry’s key.
Examples
use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); assert_eq!(map.entry("poneyland").key(), &"poneyland");
pub fn and_modify<F>(self, f: F) -> Entry<'a, K, V> where
F: FnOnce(&mut V), 1.26.0[src]
F: FnOnce(&mut V),
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); map.entry("poneyland") .and_modify(|e| { *e += 1 }) .or_insert(42); assert_eq!(map["poneyland"], 42); map.entry("poneyland") .and_modify(|e| { *e += 1 }) .or_insert(42); assert_eq!(map["poneyland"], 43);
pub fn insert(self, value: V) -> OccupiedEntry<'a, K, V>[src]
entry_insert)Sets the value of the entry, and returns an OccupiedEntry.
Examples
#![feature(entry_insert)] use std::collections::HashMap; let mut map: HashMap<&str, String> = HashMap::new(); let entry = map.entry("poneyland").insert("hoho".to_string()); assert_eq!(entry.key(), &"poneyland");
impl<'a, K, V> Entry<'a, K, V> where
V: Default, [src]
V: Default,
pub fn or_default(self) -> &'a mut VⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;1.28.0[src]
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.
Examples
use std::collections::HashMap; let mut map: HashMap<&str, Option<u32>> = HashMap::new(); map.entry("poneyland").or_default(); assert_eq!(map["poneyland"], None);