Enum otter_api_tests::hash_map::RawEntryMut [−][src]
pub enum RawEntryMut<'a, K, V, S> where
S: 'a,
K: 'a,
V: 'a, { Occupied(RawOccupiedEntryMut<'a, K, V, S>), Vacant(RawVacantEntryMut<'a, K, V, S>), }
hash_raw_entry)A view into a single entry in a map, which may either be vacant or occupied.
This is a lower-level version of Entry.
This enum is constructed through the raw_entry_mut method on HashMap,
then calling one of the methods of that RawEntryBuilderMut.
Variants
Occupied(RawOccupiedEntryMut<'a, K, V, S>)hash_raw_entry)An occupied entry.
Vacant(RawVacantEntryMut<'a, K, V, S>)hash_raw_entry)A vacant entry.
Implementations
impl<'a, K, V, S> RawEntryMut<'a, K, V, S>[src]
pub fn or_insert(self, default_key: K, default_val: V) -> (&'a mut K, &'a mut V) where
S: BuildHasher,
K: Hash, [src]
S: BuildHasher,
K: Hash,
hash_raw_entry)Ensures a value is in the entry by inserting the default if empty, and returns mutable references to the key and value in the entry.
Examples
#![feature(hash_raw_entry)] use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); map.raw_entry_mut().from_key("poneyland").or_insert("poneyland", 3); assert_eq!(map["poneyland"], 3); *map.raw_entry_mut().from_key("poneyland").or_insert("poneyland", 10).1 *= 2; assert_eq!(map["poneyland"], 6);
pub fn or_insert_with<F>(self, default: F) -> (&'a mut K, &'a mut V) where
S: BuildHasher,
K: Hash,
F: FnOnce() -> (K, V), [src]
S: BuildHasher,
K: Hash,
F: FnOnce() -> (K, V),
hash_raw_entry)Ensures a value is in the entry by inserting the result of the default function if empty, and returns mutable references to the key and value in the entry.
Examples
#![feature(hash_raw_entry)] use std::collections::HashMap; let mut map: HashMap<&str, String> = HashMap::new(); map.raw_entry_mut().from_key("poneyland").or_insert_with(|| { ("poneyland", "hoho".to_string()) }); assert_eq!(map["poneyland"], "hoho".to_string());
pub fn and_modify<F>(self, f: F) -> RawEntryMut<'a, K, V, S> where
F: FnOnce(&mut K, &mut V), [src]
F: FnOnce(&mut K, &mut V),
hash_raw_entry)Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
#![feature(hash_raw_entry)] use std::collections::HashMap; let mut map: HashMap<&str, u32> = HashMap::new(); map.raw_entry_mut() .from_key("poneyland") .and_modify(|_k, v| { *v += 1 }) .or_insert("poneyland", 42); assert_eq!(map["poneyland"], 42); map.raw_entry_mut() .from_key("poneyland") .and_modify(|_k, v| { *v += 1 }) .or_insert("poneyland", 0); assert_eq!(map["poneyland"], 43);