Struct otter_api_tests::hash_map::RandomState 1.7.0[−][src]
pub struct RandomState { /* fields omitted */ }RandomState is the default state for HashMap types.
A particular instance RandomState will create the same instances of
Hasher, but the hashers created by two different RandomState
instances are unlikely to produce the same result for the same values.
Examples
use std::collections::HashMap; use std::collections::hash_map::RandomState; let s = RandomState::new(); let mut map = HashMap::with_hasher(s); map.insert(1, 2);
Implementations
impl RandomState[src]
pub fn new() -> RandomState[src]
Constructs a new RandomState that is initialized with random keys.
Examples
use std::collections::hash_map::RandomState; let s = RandomState::new();