Struct otter_api_tests::hash_map::RawVacantEntryMut [−][src]
pub struct RawVacantEntryMut<'a, K, V, S> where
S: 'a,
K: 'a,
V: 'a, { /* fields omitted */ }🔬 This is a nightly-only experimental API. (
hash_raw_entry)A view into a vacant entry in a HashMap.
It is part of the RawEntryMut enum.
Implementations
impl<'a, K, V, S> RawVacantEntryMut<'a, K, V, S>[src]
pub fn insert(self, key: K, value: V) -> (&'a mut K, &'a mut V) where
S: BuildHasher,
K: Hash, [src]
S: BuildHasher,
K: Hash,
🔬 This is a nightly-only experimental API. (
hash_raw_entry)Sets the value of the entry with the VacantEntry’s key,
and returns a mutable reference to it.
pub fn insert_hashed_nocheck(
self,
hash: u64,
key: K,
value: V
) -> (&'a mut K, &'a mut V) where
S: BuildHasher,
K: Hash, [src]
self,
hash: u64,
key: K,
value: V
) -> (&'a mut K, &'a mut V) where
S: BuildHasher,
K: Hash,
🔬 This is a nightly-only experimental API. (
hash_raw_entry)Sets the value of the entry with the VacantEntry’s key, and returns a mutable reference to it.