Enum otter_api_tests::imports::base64::DecodeError [−]
Errors that can occur while decoding.
Variants
An invalid byte was found in the input. The offset and offending byte are provided.
The length of the input is invalid.
A typical cause of this is stray trailing whitespace or other separator bytes.
In the case where excess trailing bytes have produced an invalid length and the last byte
is also an invalid base64 symbol (as would be the case for whitespace, etc), InvalidByte
will be emitted instead of InvalidLength to make the issue easier to debug.
The last non-padding input symbol’s encoded 6 bits have nonzero bits that will be discarded. This is indicative of corrupted or truncated Base64. Unlike InvalidByte, which reports symbols that aren’t in the alphabet, this error is for symbols that are in the alphabet but represent nonsensical encodings.