Enum otter_api_tests::imports::chrono::offset::LocalResult [−][src]
pub enum LocalResult<T> {
None,
Single(T),
Ambiguous(T, T),
}The conversion result from the local time to the timezone-aware datetime types.
Variants
Given local time representation is invalid. This can occur when, for example, the positive timezone transition.
Given local time representation has a single unique result.
Given local time representation has multiple results and thus ambiguous. This can occur when, for example, the negative timezone transition.
Implementations
impl<T> LocalResult<T>[src]
pub fn single(self) -> Option<T>[src]
Returns Some only when the conversion result is unique, or None otherwise.
pub fn earliest(self) -> Option<T>[src]
Returns Some for the earliest possible conversion result, or None if none.
pub fn latest(self) -> Option<T>[src]
Returns Some for the latest possible conversion result, or None if none.
pub fn map<U, F>(self, f: F) -> LocalResult<U> where
F: FnMut(T) -> U, [src]
F: FnMut(T) -> U,
Maps a LocalResult<T> into LocalResult<U> with given function.
impl<Tz> LocalResult<Date<Tz>> where
Tz: TimeZone, [src]
Tz: TimeZone,
pub fn and_time(self, time: NaiveTime) -> LocalResult<DateTime<Tz>>[src]
Makes a new DateTime from the current date and given NaiveTime.
The offset in the current date is preserved.
Propagates any error. Ambiguous result would be discarded.
pub fn and_hms_opt(
self,
hour: u32,
min: u32,
sec: u32
) -> LocalResult<DateTime<Tz>>[src]
self,
hour: u32,
min: u32,
sec: u32
) -> LocalResult<DateTime<Tz>>
Makes a new DateTime from the current date, hour, minute and second.
The offset in the current date is preserved.
Propagates any error. Ambiguous result would be discarded.
pub fn and_hms_milli_opt(
self,
hour: u32,
min: u32,
sec: u32,
milli: u32
) -> LocalResult<DateTime<Tz>>[src]
self,
hour: u32,
min: u32,
sec: u32,
milli: u32
) -> LocalResult<DateTime<Tz>>
Makes a new DateTime from the current date, hour, minute, second and millisecond.
The millisecond part can exceed 1,000 in order to represent the leap second.
The offset in the current date is preserved.
Propagates any error. Ambiguous result would be discarded.
pub fn and_hms_micro_opt(
self,
hour: u32,
min: u32,
sec: u32,
micro: u32
) -> LocalResult<DateTime<Tz>>[src]
self,
hour: u32,
min: u32,
sec: u32,
micro: u32
) -> LocalResult<DateTime<Tz>>
Makes a new DateTime from the current date, hour, minute, second and microsecond.
The microsecond part can exceed 1,000,000 in order to represent the leap second.
The offset in the current date is preserved.
Propagates any error. Ambiguous result would be discarded.
pub fn and_hms_nano_opt(
self,
hour: u32,
min: u32,
sec: u32,
nano: u32
) -> LocalResult<DateTime<Tz>>[src]
self,
hour: u32,
min: u32,
sec: u32,
nano: u32
) -> LocalResult<DateTime<Tz>>
Makes a new DateTime from the current date, hour, minute, second and nanosecond.
The nanosecond part can exceed 1,000,000,000 in order to represent the leap second.
The offset in the current date is preserved.
Propagates any error. Ambiguous result would be discarded.
impl<T> LocalResult<T> where
T: Debug, [src]
T: Debug,