Struct otter_api_tests::imports::chrono::offset::FixedOffset [−][src]
pub struct FixedOffset { /* fields omitted */ }Expand description
Implementations
Makes a new FixedOffset for the Eastern Hemisphere with given timezone difference.
The negative secs means the Western Hemisphere.
Panics on the out-of-bound secs.
Example
use chrono::{FixedOffset, TimeZone}; let hour = 3600; let datetime = FixedOffset::east(5 * hour).ymd(2016, 11, 08) .and_hms(0, 0, 0); assert_eq!(&datetime.to_rfc3339(), "2016-11-08T00:00:00+05:00")
Makes a new FixedOffset for the Eastern Hemisphere with given timezone difference.
The negative secs means the Western Hemisphere.
Returns None on the out-of-bound secs.
Makes a new FixedOffset for the Western Hemisphere with given timezone difference.
The negative secs means the Eastern Hemisphere.
Panics on the out-of-bound secs.
Example
use chrono::{FixedOffset, TimeZone}; let hour = 3600; let datetime = FixedOffset::west(5 * hour).ymd(2016, 11, 08) .and_hms(0, 0, 0); assert_eq!(&datetime.to_rfc3339(), "2016-11-08T00:00:00-05:00")
Makes a new FixedOffset for the Western Hemisphere with given timezone difference.
The negative secs means the Eastern Hemisphere.
Returns None on the out-of-bound secs.
Returns the number of seconds to add to convert from UTC to the local time.
Returns the number of seconds to add to convert from the local time to UTC.