Enum otter_api_tests::imports::flexi_logger::LogTarget [−]
pub enum LogTarget {
StdErr,
StdOut,
File,
Writer(Box<dyn LogWriter + 'static, Global>),
FileAndWriter(Box<dyn LogWriter + 'static, Global>),
DevNull,
}Expand description
Describes the default log target.
All log messages, in which no target is explicitly defined, will be written to the default log target.
See module writers for how to specify non-default log targets in log macro calls, and the usage of non-default log writers.
Variants
Log is written to stderr.
This is the default behavior of flexi_logger.
Log is written to stdout.
Log is written to a file.
The default pattern for the filename is ‘<program_name>_<date>_<time>.<suffix>’,
e.g. myprog_2015-07-08_10-44-11.log.
Log is written to an alternative LogWriter implementation.
Log is written to a file, as with LogTarget::File, and to an alternative
LogWriter implementation.
Log is processed, including duplication, but not written to a primary target destination.
This can be useful e.g. for running application tests with all log-levels active and still avoiding tons of log files etc. Such tests ensure that the log calls which are normally not active will not cause undesired side-effects when activated (note that the log macros may prevent arguments of inactive log-calls from being evaluated).
Combined with
duplicate_to_stdout()
and
duplicate_to_stderr()
it can also be used if you want to get logs both to stdout and stderr, but not to a file.