Struct otter_api_tests::imports::flexi_logger::DeferredNow [−]
pub struct DeferredNow(_);
Deferred timestamp creation.
Is used to ensure that a log record that is sent to multiple outputs (in maybe different formats) always uses the same timestamp.
Implementations
impl<'a> DeferredNow
#[must_use]pub fn new() -> DeferredNow
#[must_use]
pub fn new() -> DeferredNowConstructs a new instance, but does not generate the timestamp.
pub fn now(&'a mut self) -> &'a DateTime<Local>
Retrieve the timestamp.
Requires mutability because the first caller will generate the timestamp.