Struct otter_api_tests::imports::flexi_logger::writers::FileLogWriter [−]
pub struct FileLogWriter { /* fields omitted */ }A configurable LogWriter implementation that writes to a file or a sequence of files.
See writers for usage guidance.
Implementations
impl FileLogWriter
#[must_use]pub fn builder() -> FileLogWriterBuilder
#[must_use]
pub fn builder() -> FileLogWriterBuilderInstantiates a builder for FileLogWriter.
pub fn format(
&self
) -> fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>
&self
) -> fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>
Returns a reference to its configured output format function.