Struct otter_api_tests::imports::log::MetadataBuilder [−][src]
pub struct MetadataBuilder<'a> { /* fields omitted */ }Builder for Metadata.
Typically should only be used by log library creators or for testing and “shim loggers”.
The MetadataBuilder can set the different parameters of a Metadata object, and returns
the created object when build is called.
Example
ⓘ
let target = "myApp"; use log::{Level, MetadataBuilder}; let metadata = MetadataBuilder::new() .level(Level::Debug) .target(target) .build();
Implementations
impl<'a> MetadataBuilder<'a>[src]
pub fn new() -> MetadataBuilder<'a>[src]
Construct a new MetadataBuilder.
The default options are:
level:Level::Infotarget:""
pub fn level(&mut self, arg: Level) -> &mut MetadataBuilder<'a>[src]
Setter for level.
pub fn target(&mut self, target: &'a str) -> &mut MetadataBuilder<'a>[src]
Setter for target.
pub fn build(&self) -> Metadata<'a>[src]
Returns a Metadata object.