Struct otter_api_tests::imports::log::Record [−][src]
pub struct Record<'a> { /* fields omitted */ }The “payload” of a log message.
Use
Record structures are passed as parameters to the log
method of the Log trait. Logger implementors manipulate these
structures in order to display log messages. Records are automatically
created by the log! macro and so are not seen by log users.
Note that the level() and target() accessors are equivalent to
self.metadata().level() and self.metadata().target() respectively.
These methods are provided as a convenience for users of this structure.
Example
The following example shows a simple logger that displays the level,
module path, and message of any Record that is passed to it.
struct SimpleLogger; impl log::Log for SimpleLogger { fn enabled(&self, metadata: &log::Metadata) -> bool { true } fn log(&self, record: &log::Record) { if !self.enabled(record.metadata()) { return; } println!("{}:{} -- {}", record.level(), record.target(), record.args()); } fn flush(&self) {} }
Implementations
impl<'a> Record<'a>[src]
pub fn builder() -> RecordBuilder<'a>[src]
Returns a new builder.
pub fn args(&self) -> &Arguments<'a>[src]
The message body.
pub fn metadata(&self) -> &Metadata<'a>[src]
Metadata about the log directive.
pub fn level(&self) -> Level[src]
The verbosity level of the message.
pub fn target(&self) -> &'a str[src]
The name of the target of the directive.
pub fn module_path(&self) -> Option<&'a str>[src]
The module path of the message.
pub fn module_path_static(&self) -> Option<&'static str>[src]
The module path of the message, if it is a 'static string.
pub fn file(&self) -> Option<&'a str>[src]
The source file containing the message.
pub fn file_static(&self) -> Option<&'static str>[src]
The module path of the message, if it is a 'static string.
pub fn line(&self) -> Option<u32>[src]
The line containing the message.