Struct otter_api_tests::imports::nix::sys::socket::UnixAddr[]

pub struct UnixAddr(pub sockaddr_un, pub usize);

A wrapper around sockaddr_un.

This also tracks the length of sun_path address (excluding a terminating null), because it may not be null-terminated. For example, unconnected and Linux abstract sockets are never null-terminated, and POSIX does not require that sun_len include the terminating null even for normal sockets. Note that the actual sockaddr length is greater by offset_of!(libc::sockaddr_un, sun_path)

Implementations

impl UnixAddr

pub fn new<P>(path: &P) -> Result<UnixAddr, Error> where
    P: NixPath + ?Sized

Create a new sockaddr_un representing a filesystem path.

pub fn new_abstract(path: &[u8]) -> Result<UnixAddr, Error>

Create a new sockaddr_un representing an address in the “abstract namespace”.

The leading null byte for the abstract namespace is automatically added; thus the input path is expected to be the bare name, not null-prefixed. This is a Linux-specific extension, primarily used to allow chrooted processes to communicate with processes having a different filesystem view.

pub fn path(&self) -> Option<&Path>

If this address represents a filesystem path, return that path.

pub fn as_abstract(&self) -> Option<&[u8]>

If this address represents an abstract socket, return its name.

For abstract sockets only the bare name is returned, without the leading null byte. None is returned for unnamed or path-backed sockets.