Enum otter_api_tests::imports::nix::sys::timerfd::ClockId[]

#[repr(i32)]
pub enum ClockId {
    CLOCK_REALTIME,
    CLOCK_MONOTONIC,
    CLOCK_BOOTTIME,
    CLOCK_REALTIME_ALARM,
    CLOCK_BOOTTIME_ALARM,
}

The type of the clock used to mark the progress of the timer. For more details on each kind of clock, please refer to timerfd_create(2).

Variants

CLOCK_REALTIME
CLOCK_MONOTONIC
CLOCK_BOOTTIME
CLOCK_REALTIME_ALARM
CLOCK_BOOTTIME_ALARM