Struct otter_api_tests::imports::regex::CaptureNames[]

pub struct CaptureNames<'r>(_);

An iterator over the names of all possible captures.

None indicates an unnamed capture; the first element (capture 0, the whole matched region) is always unnamed.

'r is the lifetime of the compiled regular expression.