Struct otter_api_tests::imports::rmp_serde::config::StructMapConfig [−]
pub struct StructMapConfig<C>(_);
Config wrapper, that overrides struct serialization by packing as a map with field names.
MessagePack specification does not tell how to serialize structs. This trait allows you to extend serialization to match your app’s requirements.
Default Serializer implementation writes structs as a tuple, i.e. only its length is encoded,
because it is the most compact representation.
Implementations
impl<C> StructMapConfig<C>
impl<C> StructMapConfig<C>pub fn new(inner: C) -> StructMapConfig<C>
pub fn new(inner: C) -> StructMapConfig<C>Creates a StructMapConfig inheriting unchanged configuration options from the given configuration.