Struct otter_api_tests::imports::rmp_serde::config::StructTupleConfig[]

pub struct StructTupleConfig<C>(_);

Config wrapper that overrides struct serlization by packing as a tuple without field names.

Implementations

impl<C> StructTupleConfig<C>

pub fn new(inner: C) -> StructTupleConfig<C>

Creates a StructTupleConfig inheriting unchanged configuration options from the given configuration.