Struct otter_api_tests::imports::rmp_serde::encode::ExtFieldSerializer [−]
pub struct ExtFieldSerializer<'a, W> { /* fields omitted */ }Trait Implementations
impl<'a, W> Debug for ExtFieldSerializer<'a, W> where
W: Debug,
W: Debug,
impl<'a, '_, W> Serializer for &'_ mut ExtFieldSerializer<'a, W> where
W: 'a + Write,
W: 'a + Write,
type Ok = ()
The output type produced by this Serializer during successful
serialization. Most serializers that produce text or binary output
should set Ok = () and serialize into an io::Write or buffer
contained within the Serializer instance. Serializers that build
in-memory data structures may be simplified by using Ok to propagate
the data structure around. Read more
type Error = Error
The error type when some error occurs during serialization.
type SerializeSeq = Impossible<(), Error>
Type returned from serialize_seq for serializing the content of the
sequence. Read more
type SerializeTuple = Impossible<(), Error>
Type returned from serialize_tuple for serializing the content of
the tuple. Read more
type SerializeTupleStruct = Impossible<(), Error>
Type returned from serialize_tuple_struct for serializing the
content of the tuple struct. Read more
type SerializeTupleVariant = Impossible<(), Error>
Type returned from serialize_tuple_variant for serializing the
content of the tuple variant. Read more
type SerializeMap = Impossible<(), Error>
Type returned from serialize_map for serializing the content of the
map. Read more
type SerializeStruct = Impossible<(), Error>
Type returned from serialize_struct for serializing the content of
the struct. Read more
type SerializeStructVariant = Impossible<(), Error>
Type returned from serialize_struct_variant for serializing the
content of the struct variant. Read more
pub fn serialize_i8(
self,
value: i8
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
value: i8
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_bytes(
self,
val: &[u8]
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
val: &[u8]
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_bool(
self,
_val: bool
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: bool
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_i16(
self,
_val: i16
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: i16
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_i32(
self,
_val: i32
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: i32
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_i64(
self,
_val: i64
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: i64
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_u8(
self,
_val: u8
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: u8
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_u16(
self,
_val: u16
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: u16
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_u32(
self,
_val: u32
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: u32
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_u64(
self,
_val: u64
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: u64
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_f32(
self,
_val: f32
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: f32
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_f64(
self,
_val: f64
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: f64
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_char(
self,
_val: char
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: char
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_str(
self,
_val: &str
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_val: &str
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_unit(
self
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_unit_struct(
self,
_name: &'static str
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_name: &'static str
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_unit_variant(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_name: &'static str,
_idx: u32,
_variant: &'static str
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_newtype_struct<T>(
self,
_name: &'static str,
_value: &T
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error> where
T: Serialize + ?Sized,
self,
_name: &'static str,
_value: &T
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error> where
T: Serialize + ?Sized,
pub fn serialize_newtype_variant<T>(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_value: &T
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error> where
T: Serialize + ?Sized,
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_value: &T
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error> where
T: Serialize + ?Sized,
pub fn serialize_none(
self
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_some<T>(
self,
_value: &T
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error> where
T: Serialize + ?Sized,
self,
_value: &T
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error> where
T: Serialize + ?Sized,
pub fn serialize_seq(
self,
_len: Option<usize>
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeSeq, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
self,
_len: Option<usize>
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeSeq, <&'_ mut ExtFieldSerializer<'a, W> as Serializer>::Error>
pub fn serialize_tuple(
self,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTuple, Error>
self,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTuple, Error>
pub fn serialize_tuple_struct(
self,
_name: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleStruct, Error>
self,
_name: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleStruct, Error>
pub fn serialize_tuple_variant(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleVariant, Error>
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleVariant, Error>
pub fn serialize_map(
self,
_len: Option<usize>
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeMap, Error>
self,
_len: Option<usize>
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeMap, Error>
pub fn serialize_struct(
self,
_name: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStruct, Error>
self,
_name: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStruct, Error>
pub fn serialize_struct_variant(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStructVariant, Error>
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_len: usize
) -> Result<<&'_ mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStructVariant, Error>
pub fn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>[src]
pub fn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>[src]
pub fn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Serialize, [src]
I: IntoIterator,
<I as IntoIterator>::Item: Serialize,
pub fn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
K: Serialize,
V: Serialize,
I: IntoIterator<Item = (K, V)>, [src]
K: Serialize,
V: Serialize,
I: IntoIterator<Item = (K, V)>,
pub fn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Display + ?Sized, [src]
T: Display + ?Sized,
pub fn is_human_readable(&self) -> bool[src]