Struct otter_api_tests::imports::rmp_serde::encode::Serializer [−]
pub struct Serializer<W, C = DefaultConfig> { /* fields omitted */ }
Represents MessagePack serialization implementation.
Note
MessagePack has no specification about how to encode enum types. Thus we are free to do whatever we want, so the given choice may be not ideal for you.
An enum value is represented as a single-entry map whose key is the variant id and whose value is a sequence containing all associated data. If the enum does not have associated data, the sequence is empty.
All instances of ErrorKind::Interrupted are handled by this function and the underlying
operation is retried.
Implementations
impl<W, C> Serializer<W, C> where
W: Write,
W: Write,
pub fn get_ref(&self) -> &WⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Gets a reference to the underlying writer.
pub fn get_mut(&mut self) -> &mut WⓘNotable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;
Notable traits for &'_ mut R
impl<'_, R> Read for &'_ mut R where
R: Read + ?Sized, impl<'_, W> Write for &'_ mut W where
W: Write + ?Sized, impl<'_, I> Iterator for &'_ mut I where
I: Iterator + ?Sized, type Item = <I as Iterator>::Item;impl<'_, F> Future for &'_ mut F where
F: Future + Unpin + ?Sized, type Output = <F as Future>::Output;Gets a mutable reference to the underlying writer.
It is inadvisable to directly write to the underlying writer.
pub fn into_inner(self) -> W
Unwraps this Serializer, returning the underlying writer.
impl<W> Serializer<W, DefaultConfig> where
W: Write,
W: Write,
pub fn new(wr: W) -> Serializer<W, DefaultConfig>
Constructs a new MessagePack serializer whose output will be written to the writer
specified.
Note
This is the default constructor, which returns a serializer that will serialize structs and enums using the most compact representation.
impl<W, C> Serializer<W, C> where
W: Write,
W: Write,
pub fn with_struct_map(self) -> Serializer<W, StructMapConfig<C>>
Consumes this serializer returning the new one, which will serialize structs as a map.
This is used, when the default struct serialization as a tuple does not fit your requirements.
pub fn with_struct_tuple(self) -> Serializer<W, StructTupleConfig<C>>
Consumes this serializer returning the new one, which will serialize structs as a tuple without field names.
This is the default MessagePack serialization mechanism, emitting the most compact representation.
pub fn with_string_variants(self) -> Serializer<W, VariantStringConfig<C>>
Consumes this serializer returning the new one, which will serialize enum variants as strings.
This is used, when the default struct serialization as integers does not fit your requirements.
pub fn with_integer_variants(self) -> Serializer<W, VariantIntegerConfig<C>>
Consumes this serializer returning the new one, which will serialize enum variants as a their integer indices.
This is the default MessagePack serialization mechanism, emitting the most compact representation.
pub fn with_human_readable(self) -> Serializer<W, HumanReadableConfig<C>>
Consumes this serializer returning the new one, which will serialize some types in
human-readable representations (Serializer::is_human_readable will return true). Note
that the overall representation is still binary, but some types such as IP addresses will
be saved as human-readable strings.
This is primarily useful if you need to interoperate with serializations produced by older
versions of rmp-serde.
pub fn with_binary(self) -> Serializer<W, BinaryConfig<C>>
Consumes this serializer returning the new one, which will serialize types as binary
(Serializer::is_human_readable will return false).
This is the default MessagePack serialization mechanism, emitting the most compact representation.