pub struct AssertUnwindSafe<T>(pub T);Expand description
A simple wrapper around a type to assert that it is unwind safe.
When using catch_unwind it may be the case that some of the closed over
variables are not unwind safe. For example if &mut T is captured the
compiler will generate a warning indicating that it is not unwind safe. It
might not be the case, however, that this is actually a problem due to the
specific usage of catch_unwind if unwind safety is specifically taken into
account. This wrapper struct is useful for a quick and lightweight
annotation that a variable is indeed unwind safe.
Examples
One way to use AssertUnwindSafe is to assert that the entire closure
itself is unwind safe, bypassing all checks for all variables:
use std::panic::{self, AssertUnwindSafe};
let mut variable = 4;
// This code will not compile because the closure captures `&mut variable`
// which is not considered unwind safe by default.
// panic::catch_unwind(|| {
// variable += 3;
// });
// This, however, will compile due to the `AssertUnwindSafe` wrapper
let result = panic::catch_unwind(AssertUnwindSafe(|| {
variable += 3;
}));
// ...Wrapping the entire closure amounts to a blanket assertion that all captured variables are unwind safe. This has the downside that if new captures are added in the future, they will also be considered unwind safe. Therefore, you may prefer to just wrap individual captures, as shown below. This is more annotation, but it ensures that if a new capture is added which is not unwind safe, you will get a compilation error at that time, which will allow you to consider whether that new capture in fact represent a bug or not.
use std::panic::{self, AssertUnwindSafe};
let mut variable = 4;
let other_capture = 3;
let result = {
let mut wrapper = AssertUnwindSafe(&mut variable);
panic::catch_unwind(move || {
**wrapper += other_capture;
})
};
// ...Tuple Fields
0: TTrait Implementations
Sourceimpl<S> AsyncIterator for AssertUnwindSafe<S>where
S: AsyncIterator,
impl<S> AsyncIterator for AssertUnwindSafe<S>where
S: AsyncIterator,
Sourcetype Item = <S as AsyncIterator>::Item
type Item = <S as AsyncIterator>::Item
async_iterator)Sourcefn poll_next(
self: Pin<&mut AssertUnwindSafe<S>>,
cx: &mut Context<'_>,
) -> Poll<Option<<S as AsyncIterator>::Item>>
fn poll_next( self: Pin<&mut AssertUnwindSafe<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<S as AsyncIterator>::Item>>
async_iterator)None if the async iterator is exhausted. Read more1.16.0 · Sourceimpl<T> Debug for AssertUnwindSafe<T>where
T: Debug,
impl<T> Debug for AssertUnwindSafe<T>where
T: Debug,
1.62.0 · Sourceimpl<T> Default for AssertUnwindSafe<T>where
T: Default,
impl<T> Default for AssertUnwindSafe<T>where
T: Default,
1.9.0 (const: unstable) · Sourceimpl<T> Deref for AssertUnwindSafe<T>
impl<T> Deref for AssertUnwindSafe<T>
1.9.0 (const: unstable) · Sourceimpl<T> DerefMut for AssertUnwindSafe<T>
impl<T> DerefMut for AssertUnwindSafe<T>
1.9.0 · Sourceimpl<R, F> FnOnce() for AssertUnwindSafe<F>where
F: FnOnce() -> R,
impl<R, F> FnOnce() for AssertUnwindSafe<F>where
F: FnOnce() -> R,
1.96.0 · Sourceimpl<T> From<T> for AssertUnwindSafe<T>where
T: UnwindSafe,
If a value’s type is already UnwindSafe,
wrapping it in AssertUnwindSafe is never incorrect.
impl<T> From<T> for AssertUnwindSafe<T>where
T: UnwindSafe,
If a value’s type is already UnwindSafe,
wrapping it in AssertUnwindSafe is never incorrect.
Sourcefn from(value: T) -> AssertUnwindSafe<T> ⓘ
fn from(value: T) -> AssertUnwindSafe<T> ⓘ
Sourceimpl<F> FusedFuture for AssertUnwindSafe<F>where
F: FusedFuture,
Available on crate feature std only.
impl<F> FusedFuture for AssertUnwindSafe<F>where
F: FusedFuture,
std only.Sourcefn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
true if the underlying future should no longer be polled.1.36.0 · Sourceimpl<F> Future for AssertUnwindSafe<F>where
F: Future,
impl<F> Future for AssertUnwindSafe<F>where
F: Future,
Sourceimpl<S> Stream for AssertUnwindSafe<S>where
S: Stream,
Available on crate feature std only.
impl<S> Stream for AssertUnwindSafe<S>where
S: Stream,
std only.Sourcefn poll_next(
self: Pin<&mut AssertUnwindSafe<S>>,
cx: &mut Context<'_>,
) -> Poll<Option<<S as Stream>::Item>>
fn poll_next( self: Pin<&mut AssertUnwindSafe<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<S as Stream>::Item>>
None if the stream is exhausted. Read moreimpl<T> RefUnwindSafe for AssertUnwindSafe<T>
impl<T> UnwindSafe for AssertUnwindSafe<T>