Enum otter_api_tests::mpsc::RecvTimeoutError 1.12.0[−][src]
pub enum RecvTimeoutError {
Timeout,
Disconnected,
}This enumeration is the list of possible errors that made recv_timeout
unable to return data when called. This can occur with both a channel and
a sync_channel.
Variants
This channel is currently empty, but the Sender(s) have not yet disconnected, so data may yet become available.
The channel’s sending half has become disconnected, and there will never be any more data received on it.