Sender

Struct Sender 

1.0.0 · Source
pub struct Sender<T> { /* private fields */ }
The sending-half of Rust’s asynchronous channel type.

Messages can be sent through this channel with send.

Note: all senders (the original and its clones) need to be dropped for the receiver to stop blocking to receive messages with Receiver::recv.

Examples

use std::sync::mpsc::channel;
use std::thread;

let (sender, receiver) = channel();
let sender2 = sender.clone();

// First thread owns sender
thread::spawn(move || {
    sender.send(1).unwrap();
});

// Second thread owns sender2
thread::spawn(move || {
    sender2.send(2).unwrap();
});

let msg = receiver.recv().unwrap();
let msg2 = receiver.recv().unwrap();

assert_eq!(3, msg + msg2);

Implementations

Source

impl<T> Sender<T>

1.0.0 · Source

pub fn send(&self, t: T) -> Result<(), SendError<T>>

Attempts to send a value on this channel, returning it back if it could not be sent.

A successful send occurs when it is determined that the other end of the channel has not hung up already. An unsuccessful send would be one where the corresponding receiver has already been deallocated. Note that a return value of Err means that the data will never be received, but a return value of Ok does not mean that the data will be received. It is possible for the corresponding receiver to hang up immediately after this function returns Ok.

This method will never block the current thread.

Examples
use std::sync::mpsc::channel;

let (tx, rx) = channel();

// This send is always successful
tx.send(1).unwrap();

// This send will fail because the receiver is gone
drop(rx);
assert_eq!(tx.send(1).unwrap_err().0, 1);
pub fn is_disconnected(&self) -> bool

🔬This is a nightly-only experimental API. (mpsc_is_disconnected)

Returns true if the channel is disconnected.

Note that a return value of false does not guarantee the channel will remain connected. The channel may be disconnected immediately after this method returns, so a subsequent Sender::send may still fail with SendError.

Examples
#![feature(mpsc_is_disconnected)]

use std::sync::mpsc::channel;

let (tx, rx) = channel::<i32>();
assert!(!tx.is_disconnected());
drop(rx);
assert!(tx.is_disconnected());