Module sync
otter_
api_
tests
1.2.1
Module sync
Module Items
Structs
In otter_
api_
tests::
once_
cell
otter_api_tests
::
once_cell
Module
sync
Thread-safe, blocking version of
OnceCell
.
Structs

Lazy
A value which is initialized on the first access.
Once
Cell
A thread-safe cell which can be written to only once.