Enum otter_api_tests::serde_json::error::Category [−][src]
pub enum Category {
Io,
Syntax,
Data,
Eof,
}Expand description
Categorizes the cause of a serde_json::Error.
Variants
The error was caused by a failure to read or write bytes on an IO stream.
The error was caused by input that was not syntactically valid JSON.
The error was caused by input data that was semantically incorrect.
For example, JSON containing a number is semantically incorrect when the type being deserialized into holds a String.
The error was caused by prematurely reaching the end of the input data.
Callers that process streaming input may be interested in retrying the deserialization once more data is available.