Enum otter_api_tests::serde_json::map::Entry [−][src]
pub enum Entry<'a> {
Vacant(VacantEntry<'a>),
Occupied(OccupiedEntry<'a>),
}A view into a single entry in a map, which may either be vacant or occupied.
This enum is constructed from the entry method on Map.
Variants
Vacant(VacantEntry<'a>)A vacant Entry.
Occupied(OccupiedEntry<'a>)An occupied Entry.
Implementations
impl<'a> Entry<'a>[src]
pub fn key(&self) -> &String[src]
Returns a reference to this entry’s key.
Examples
let mut map = serde_json::Map::new(); assert_eq!(map.entry("serde").key(), &"serde");
pub fn or_insert(self, default: Value) -> &'a mut Value[src]
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
let mut map = serde_json::Map::new(); map.entry("serde").or_insert(json!(12)); assert_eq!(map["serde"], 12);
pub fn or_insert_with<F>(self, default: F) -> &'a mut Value where
F: FnOnce() -> Value, [src]
F: FnOnce() -> Value,
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
let mut map = serde_json::Map::new(); map.entry("serde").or_insert_with(|| json!("hoho")); assert_eq!(map["serde"], "hoho".to_owned());
pub fn and_modify<F>(self, f: F) -> Entry<'a> where
F: FnOnce(&mut Value), [src]
F: FnOnce(&mut Value),
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
let mut map = serde_json::Map::new(); map.entry("serde") .and_modify(|e| *e = json!("rust")) .or_insert(json!("cpp")); assert_eq!(map["serde"], "cpp"); map.entry("serde") .and_modify(|e| *e = json!("rust")) .or_insert(json!("cpp")); assert_eq!(map["serde"], "rust");