Struct otter_api_tests::GenericSimpleShape [−][src]
pub struct GenericSimpleShape<Desc, Outl> {
pub desc: Desc,
pub edges: IndexVec<FaceId, Html>,
pub edge_width: f64,
pub itemname: String,
pub outline: Outl,
// some fields omitted
}Fields
desc: Descedges: IndexVec<FaceId, Html>edge_width: f64itemname: Stringoutline: OutlImplementations
impl<Desc, Outl> GenericSimpleShape<Desc, Outl> where
Desc: Debug + Send + Sync + 'static,
Outl: 'static + OutlineTrait, [src]
impl<Desc, Outl> GenericSimpleShape<Desc, Outl> where
Desc: Debug + Send + Sync + 'static,
Outl: 'static + OutlineTrait, [src]pub fn new(
desc: Desc,
outline: Outl,
def_itemname: &str,
common: &SimpleCommon
) -> Result<GenericSimpleShape<Desc, Outl>, SpecError>[src]pub fn svg_piece_raw(
&self,
f: &mut Html,
face: FaceId,
stroke_attrs_hook: &mut dyn FnMut(&mut Html)
) -> Result<(), InternalError>[src]Trait Implementations
impl<Desc, Outl> DerivedDynCast<ConcreteDynCastConfig<dyn OutlineTrait + 'static, dyn OutlineTrait + 'static>, <dyn OutlineTrait + 'static as GetDynCastConfig<dyn OutlineTrait + 'static>>::Config> for GenericSimpleShape<Desc, Outl> where
Desc: Debug + Send + Sync + 'static,
Outl: OutlineTrait + 'static, [src]
impl<Desc, Outl> DerivedDynCast<ConcreteDynCastConfig<dyn OutlineTrait + 'static, dyn OutlineTrait + 'static>, <dyn OutlineTrait + 'static as GetDynCastConfig<dyn OutlineTrait + 'static>>::Config> for GenericSimpleShape<Desc, Outl> where
Desc: Debug + Send + Sync + 'static,
Outl: OutlineTrait + 'static, [src]pub fn derived_dyn_cast_ref(
&self
) -> Result<&(dyn OutlineTrait + 'static), &(dyn OutlineTrait + 'static)>[src]
pub fn derived_dyn_cast_ref(
&self
) -> Result<&(dyn OutlineTrait + 'static), &(dyn OutlineTrait + 'static)>[src]Cast a shared reference of this trait object to another trait object.
pub fn derived_dyn_cast_mut(
&mut self
) -> Result<&mut (dyn OutlineTrait + 'static), &mut (dyn OutlineTrait + 'static)>[src]
pub fn derived_dyn_cast_mut(
&mut self
) -> Result<&mut (dyn OutlineTrait + 'static), &mut (dyn OutlineTrait + 'static)>[src]Cast a mutable/unique reference of this trait object to another trait object.
pub fn derived_dyn_cast_boxed(
self: Box<GenericSimpleShape<Desc, Outl>, Global>
) -> Result<Box<dyn OutlineTrait + 'static, Global>, Box<dyn OutlineTrait + 'static, Global>>[src]
pub fn derived_dyn_cast_boxed(
self: Box<GenericSimpleShape<Desc, Outl>, Global>
) -> Result<Box<dyn OutlineTrait + 'static, Global>, Box<dyn OutlineTrait + 'static, Global>>[src]Cast a boxed trait object to another trait object.
pub fn derived_dyn_cast_rc(
self: Rc<GenericSimpleShape<Desc, Outl>>
) -> Result<Rc<dyn OutlineTrait + 'static>, Rc<dyn OutlineTrait + 'static>>[src]
pub fn derived_dyn_cast_rc(
self: Rc<GenericSimpleShape<Desc, Outl>>
) -> Result<Rc<dyn OutlineTrait + 'static>, Rc<dyn OutlineTrait + 'static>>[src]Cast a reference counted trait object to another trait object.
pub fn derived_dyn_cast_arc(
self: Arc<GenericSimpleShape<Desc, Outl>>
) -> Result<Arc<dyn OutlineTrait + 'static>, Arc<dyn OutlineTrait + 'static>>[src]
pub fn derived_dyn_cast_arc(
self: Arc<GenericSimpleShape<Desc, Outl>>
) -> Result<Arc<dyn OutlineTrait + 'static>, Arc<dyn OutlineTrait + 'static>>[src]Cast an atomically reference counted trait object to another trait object.
impl<'de, Desc, Outl> Deserialize<'de> for GenericSimpleShape<Desc, Outl> where
Desc: Deserialize<'de>,
Outl: Deserialize<'de>, [src]
impl<'de, Desc, Outl> Deserialize<'de> for GenericSimpleShape<Desc, Outl> where
Desc: Deserialize<'de>,
Outl: Deserialize<'de>, [src]pub fn deserialize<__D>(
__deserializer: __D
) -> Result<GenericSimpleShape<Desc, Outl>, <__D as Deserializer<'de>>::Error> where
__D: Deserializer<'de>, [src]
pub fn deserialize<__D>(
__deserializer: __D
) -> Result<GenericSimpleShape<Desc, Outl>, <__D as Deserializer<'de>>::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
impl<Desc, Outl> OutlineTrait for GenericSimpleShape<Desc, Outl> where
Desc: Debug + Send + Sync + 'static,
Outl: 'static + OutlineTrait, [src]
impl<Desc, Outl> OutlineTrait for GenericSimpleShape<Desc, Outl> where
Desc: Debug + Send + Sync + 'static,
Outl: 'static + OutlineTrait, [src]pub fn svg_piece(
&self,
f: &mut Html,
gpc: &GPiece,
_gs: &GameState,
_vpid: VisiblePieceId
) -> Result<(), InternalError>[src]pub fn describe_html(
&self,
gpc: &GPiece,
_goccults: &GameOccults
) -> Result<Html, InternalError>[src]fn add_ui_operations(
&self,
ShowUnocculted,
_upd: &mut Vec<UoDescription, Global>,
_gs: &GameState,
_gpc: &GPiece
) -> Result<(), InternalError>[src]fn ui_operation(
&self,
ShowUnocculted,
_a: ApiPieceOpArgs<'_>,
_opname: &str,
_wrc: WhatResponseToClientOp
) -> Result<(PieceUpdate, Option<Box<dyn FnOnce(&'r mut PrepareUpdatesBuffer<'_>) + 'static, Global>>), ApiPieceOpError>[src]fn held_change_hook(
&self,
_ig: &InstanceRef,
_gpieces: &mut GPieces,
_piece: PieceId,
_was_held: Option<PlayerId>
) -> Result<Option<Box<dyn FnOnce(&'r mut PrepareUpdatesBuffer<'_>) + 'static, Global>>, InternalError>[src]
fn held_change_hook(
&self,
_ig: &InstanceRef,
_gpieces: &mut GPieces,
_piece: PieceId,
_was_held: Option<PlayerId>
) -> Result<Option<Box<dyn FnOnce(&'r mut PrepareUpdatesBuffer<'_>) + 'static, Global>>, InternalError>[src]Piece is responsible for dealing with the possibility that they may be occulted! Read more
fn loaded_hook(
&self,
_piece: PieceId,
_gs: &mut GameState,
_ig: &InstanceRef
) -> Result<(), InternalError>[src]Not called if the whole game is destroyed. You can use Drop of course but it’s not usually much use since you don’t have a reference to the game or anything. Read more
fn occultation_notify_hook(
&self,
_piece: PieceId
) -> Option<Box<dyn FnOnce(&'r mut PrepareUpdatesBuffer<'_>) + 'static, Global>>[src]impl<Desc, Outl> Serialize for GenericSimpleShape<Desc, Outl> where
Desc: Serialize,
Outl: Serialize, [src]
impl<Desc, Outl> Serialize for GenericSimpleShape<Desc, Outl> where
Desc: Serialize,
Outl: Serialize, [src]pub fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer, [src]
pub fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer, [src]Serialize this value into the given Serde serializer. Read more