pub struct VisiblePieceId(pub KeyData);Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl Clone for VisiblePieceId
impl Clone for VisiblePieceId
Sourcefn clone(&self) -> VisiblePieceId
fn clone(&self) -> VisiblePieceId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VisiblePieceId
impl Debug for VisiblePieceId
Sourceimpl Default for VisiblePieceId
impl Default for VisiblePieceId
Sourcefn default() -> VisiblePieceId
fn default() -> VisiblePieceId
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for VisiblePieceId
impl<'de> Deserialize<'de> for VisiblePieceId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VisiblePieceId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VisiblePieceId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for VisiblePieceId
impl Display for VisiblePieceId
Sourceimpl From<KeyData> for VisiblePieceId
impl From<KeyData> for VisiblePieceId
Sourcefn from(d: KeyData) -> VisiblePieceId
fn from(d: KeyData) -> VisiblePieceId
Converts to this type from the input type.
Sourceimpl From<VisiblePieceId> for KeyData
impl From<VisiblePieceId> for KeyData
Sourcefn from(p: VisiblePieceId) -> KeyData
fn from(p: VisiblePieceId) -> KeyData
Converts to this type from the input type.
Sourceimpl From<VisiblePieceId> for String
impl From<VisiblePieceId> for String
Sourcefn from(p: VisiblePieceId) -> String
fn from(p: VisiblePieceId) -> String
Converts to this type from the input type.
Sourceimpl Hash for VisiblePieceId
impl Hash for VisiblePieceId
Sourceimpl<'e> HtmlFormat<'e> for VisiblePieceId
impl<'e> HtmlFormat<'e> for VisiblePieceId
type Encoded = &'e VisiblePieceId
fn html_format<'f>(&'f self) -> <VisiblePieceId as HtmlFormat<'e>>::Encodedwhere
'f: 'e,
Sourceimpl Key for VisiblePieceId
impl Key for VisiblePieceId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for VisiblePieceId
impl Ord for VisiblePieceId
Sourcefn cmp(&self, other: &VisiblePieceId) -> Ordering
fn cmp(&self, other: &VisiblePieceId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VisiblePieceId
impl PartialEq for VisiblePieceId
Sourcefn eq(&self, other: &VisiblePieceId) -> bool
fn eq(&self, other: &VisiblePieceId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VisiblePieceId
impl PartialOrd for VisiblePieceId
Sourceimpl Serialize for VisiblePieceId
impl Serialize for VisiblePieceId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<&str> for VisiblePieceId
impl TryFrom<&str> for VisiblePieceId
Sourceimpl TryFrom<String> for VisiblePieceId
impl TryFrom<String> for VisiblePieceId
impl Copy for VisiblePieceId
impl Eq for VisiblePieceId
impl StructuralPartialEq for VisiblePieceId