Struct otter_api_tests::time::SystemTimeError 1.8.0[−][src]
pub struct SystemTimeError(_);
An error returned from the duration_since and elapsed methods on
SystemTime, used to learn how far in the opposite direction a system time
lies.
Examples
use std::thread::sleep; use std::time::{Duration, SystemTime}; let sys_time = SystemTime::now(); sleep(Duration::from_secs(1)); let new_sys_time = SystemTime::now(); match sys_time.duration_since(new_sys_time) { Ok(_) => {} Err(e) => println!("SystemTimeError difference: {:?}", e.duration()), }
Implementations
Returns the positive duration which represents how far forward the second system time was from the first.
A SystemTimeError is returned from the SystemTime::duration_since
and SystemTime::elapsed methods whenever the second system time
represents a point later in time than the self of the method call.
Examples
use std::thread::sleep; use std::time::{Duration, SystemTime}; let sys_time = SystemTime::now(); sleep(Duration::from_secs(1)); let new_sys_time = SystemTime::now(); match sys_time.duration_since(new_sys_time) { Ok(_) => {} Err(e) => println!("SystemTimeError difference: {:?}", e.duration()), }