InertPieceTrait

Trait InertPieceTrait 

pub trait InertPieceTrait:
    PieceBaseTrait
    + Serialize
    + Deserialize {
    // Required methods
    fn svg(
        &self,
        f: &mut Html,
        id: VisiblePieceId,
        face: FaceId,
        xdata: &Option<Box<dyn PieceXData>>,
    ) -> Result<(), InternalError>;
    fn describe_html(&self, face: FaceId) -> Result<Html, InternalError>;
}

Required Methods

fn svg( &self, f: &mut Html, id: VisiblePieceId, face: FaceId, xdata: &Option<Box<dyn PieceXData>>, ) -> Result<(), InternalError>

When used for occultated version of another object, face used is always default, regardless of nfaces. This is always the case for a piece whose PieceSpec::load returns Some for occultation, but which does not provide a nontrivial PieceSpec::load_inert.

fn describe_html(&self, face: FaceId) -> Result<Html, InternalError>