PieceXData

Trait PieceXData 

pub trait PieceXData:
    Downcast
    + Debug
    + Send
    + 'static
    + Serialize
    + Deserialize {
    // Required method
    fn dummy() -> Self
       where Self: Sized;
}

Required Methods

fn dummy() -> Self
where Self: Sized,

Implementations

Source

impl dyn PieceXData

pub fn is<__T>(&self) -> bool
where __T: PieceXData,

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T>( self: Box<dyn PieceXData>, ) -> Result<Box<__T>, Box<dyn PieceXData>>
where __T: PieceXData,

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T>( self: Rc<dyn PieceXData>, ) -> Result<Rc<__T>, Rc<dyn PieceXData>>
where __T: PieceXData,

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T>(&self) -> Option<&__T>
where __T: PieceXData,

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T>(&mut self) -> Option<&mut __T>
where __T: PieceXData,

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.