Enum otter_api_tests::unistd::PathconfVar [−]
#[repr(i32)]
pub enum PathconfVar {
Show variants
FILESIZEBITS,
LINK_MAX,
MAX_CANON,
MAX_INPUT,
NAME_MAX,
PATH_MAX,
PIPE_BUF,
POSIX2_SYMLINKS,
POSIX_ALLOC_SIZE_MIN,
POSIX_REC_INCR_XFER_SIZE,
POSIX_REC_MAX_XFER_SIZE,
POSIX_REC_MIN_XFER_SIZE,
POSIX_REC_XFER_ALIGN,
SYMLINK_MAX,
_POSIX_CHOWN_RESTRICTED,
_POSIX_NO_TRUNC,
_POSIX_VDISABLE,
_POSIX_ASYNC_IO,
_POSIX_PRIO_IO,
_POSIX_SYNC_IO,
}Variable names for pathconf
Nix uses the same naming convention for these variables as the
getconf(1) utility.
That is, PathconfVar variables have the same name as the abstract
variables shown in the pathconf(2) man page. Usually, it’s the same as
the C variable name without the leading _PC_.
POSIX 1003.1-2008 standardizes all of these variables, but some OSes choose not to implement variables that cannot change at runtime.
References
Variants
Minimum number of bits needed to represent, as a signed integer value, the maximum size of a regular file allowed in the specified directory.
Maximum number of links to a single file.
Maximum number of bytes in a terminal canonical input line.
Minimum number of bytes for which space is available in a terminal input queue; therefore, the maximum number of bytes a conforming application may require to be typed as input before reading them.
Maximum number of bytes in a filename (not including the terminating null of a filename string).
Maximum number of bytes the implementation will store as a pathname in a user-supplied buffer of unspecified size, including the terminating null character. Minimum number the implementation will accept as the maximum number of bytes in a pathname.
Maximum number of bytes that is guaranteed to be atomic when writing to a pipe.
Symbolic links can be created.
Minimum number of bytes of storage actually allocated for any portion of a file.
Recommended increment for file transfer sizes between the
POSIX_REC_MIN_XFER_SIZE and POSIX_REC_MAX_XFER_SIZE values.
Maximum recommended file transfer size.
Minimum recommended file transfer size.
Recommended file transfer buffer alignment.
Maximum number of bytes in a symbolic link.
The use of chown and fchown is restricted to a process with
appropriate privileges, and to changing the group ID of a file only to
the effective group ID of the process or to one of its supplementary
group IDs.
Pathname components longer than {NAME_MAX} generate an error.
This symbol shall be defined to be the value of a character that shall disable terminal special character handling.
Asynchronous input or output operations may be performed for the associated file.
Prioritized input or output operations may be performed for the associated file.
Synchronized input or output operations may be performed for the associated file.