Enum otter_api_tests::unistd::Whence[]

#[repr(i32)]
pub enum Whence {
    SeekSet,
    SeekCur,
    SeekEnd,
    SeekData,
    SeekHole,
}

Directive that tells lseek and lseek64 what the offset is relative to.

Variants

SeekSet

Specify an offset relative to the start of the file.

SeekCur

Specify an offset relative to the current file location.

SeekEnd

Specify an offset relative to the end of the file.

SeekData

Specify an offset relative to the next location in the file greater than or equal to offset that contains some data. If offset points to some data, then the file offset is set to offset.

SeekHole

Specify an offset relative to the next hole in the file greater than or equal to offset. If offset points into the middle of a hole, then the file offset should be set to offset. If there is no hole past offset, then the file offset should be adjusted to the end of the file (i.e., there is an implicit hole at the end of any file).