Struct otter_api_tests::unistd::User[]

pub struct User {
    pub name: String,
    pub passwd: CString,
    pub uid: Uid,
    pub gid: Gid,
    pub gecos: CString,
    pub dir: PathBuf,
    pub shell: PathBuf,
}

Representation of a User, based on libc::passwd

The reason some fields in this struct are String and others are CString is because some fields are based on the user’s locale, which could be non-UTF8, while other fields are guaranteed to conform to NAME_REGEX, which only contains ASCII.

Fields

name: String

Username

passwd: CString

User password (probably encrypted)

uid: Uid

User ID

gid: Gid

Group ID

gecos: CString

User information

dir: PathBuf

Home directory

shell: PathBuf

Path to shell

Implementations

impl User

pub fn from_uid(uid: Uid) -> Result<Option<User>, Error>

Get a user by UID.

Internally, this function calls getpwuid_r(3)

Examples

use nix::unistd::{Uid, User};
// Returns an Result<Option<User>>, thus the double unwrap.
let res = User::from_uid(Uid::from_raw(0)).unwrap().unwrap();
assert!(res.name == "root");

pub fn from_name(name: &str) -> Result<Option<User>, Error>

Get a user by name.

Internally, this function calls getpwnam_r(3)

Examples

use nix::unistd::User;
// Returns an Result<Option<User>>, thus the double unwrap.
let res = User::from_name("root").unwrap().unwrap();
assert!(res.name == "root");