Trait otter_api_tests::unix::thread::JoinHandleExt 1.9.0[−][src]
pub trait JoinHandleExt {
fn as_pthread_t(&self) -> u64;
fn into_pthread_t(self) -> u64;
}This is supported on Unix only.
Unix-specific extensions to JoinHandle.
Required methods
fn as_pthread_t(&self) -> u64[src]
fn as_pthread_t(&self) -> u64[src]Extracts the raw pthread_t without taking ownership
fn into_pthread_t(self) -> u64[src]
fn into_pthread_t(self) -> u64[src]Consumes the thread, returning the raw pthread_t
This function transfers ownership of the underlying pthread_t to the caller. Callers are then the unique owners of the pthread_t and must either detach or join the pthread_t once it’s no longer needed.
Implementations on Foreign Types
impl<'_, T> JoinHandleExt for ScopedJoinHandle<'_, T>
impl<'_, T> JoinHandleExt for ScopedJoinHandle<'_, T>pub fn as_pthread_t(&self) -> u64pub fn into_pthread_t(self) -> u64