Struct otter_api_tests::zipfile::write::FileOptions [−]
pub struct FileOptions { /* fields omitted */ }Expand description
Metadata for a file to be written
Implementations
impl FileOptions
impl FileOptionspub fn default() -> FileOptions
pub fn default() -> FileOptionsConstruct a new FileOptions object
pub fn compression_method(self, method: CompressionMethod) -> FileOptions
pub fn compression_method(self, method: CompressionMethod) -> FileOptionsSet the compression method for the new file
The default is CompressionMethod::Deflated. If the deflate compression feature is
disabled, CompressionMethod::Stored becomes the default.
pub fn last_modified_time(self, mod_time: DateTime) -> FileOptions
pub fn last_modified_time(self, mod_time: DateTime) -> FileOptionsSet the last modified time
The default is the current timestamp if the ‘time’ feature is enabled, and 1980-01-01 otherwise
pub fn unix_permissions(self, mode: u32) -> FileOptions
pub fn unix_permissions(self, mode: u32) -> FileOptionsSet the permissions for the new file.
The format is represented with unix-style permissions.
The default is 0o644, which represents rw-r--r-- for files,
and 0o755, which represents rwxr-xr-x for directories
pub fn large_file(self, large: bool) -> FileOptions
pub fn large_file(self, large: bool) -> FileOptionsSet whether the new file’s compressed and uncompressed size is less than 4 GiB.
If set to false and the file exceeds the limit, an I/O error is thrown. If set to true,
readers will require ZIP64 support and if the file does not exceed the limit, 20 B are
wasted. The default is false.