pub trait DynCastConfigTargetTest<C>where
C: ?Sized,{ }Expand description
Used by macros to determine if a type can be coerced to a “config” type’s target trait.
If a config type implements DynCastConfigTargetTest<T> for a type T then
that type can be coerced to the trait defined by <C as DynCastConfig>::Target.
This is used by the impl_dyn_cast macro to determine if it should generate
code that coerces a type to the target trait or to the source trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".