Enum otter_api_tests::flexi_logger::Cleanup [−]
pub enum Cleanup {
Never,
KeepLogFiles(usize),
}Defines the strategy for handling older log files.
Is used in Logger::rotate.
Note that if you use a strategy other than Cleanup::Never, then the cleanup work is
by default done in an extra thread, to minimize the impact on the program.
See
Logger::cleanup_in_background_thread
if you want to control whether this extra thread is created and used.
Variants
Older log files are not touched - they remain for ever.
KeepLogFiles(usize)The specified number of rotated log files are kept. Older files are deleted, if necessary.