Struct otter_api_tests::imports::chrono::format::DelayedFormat [−][src]
pub struct DelayedFormat<I> { /* fields omitted */ }A temporary object which can be used as an argument to format! or others.
This is normally constructed via format methods of each date and time type.
Implementations
impl<'a, I, B> DelayedFormat<I> where
B: Borrow<Item<'a>>,
I: Iterator<Item = B> + Clone, [src]
B: Borrow<Item<'a>>,
I: Iterator<Item = B> + Clone,
pub fn new(
date: Option<NaiveDate>,
time: Option<NaiveTime>,
items: I
) -> DelayedFormat<I>[src]
date: Option<NaiveDate>,
time: Option<NaiveTime>,
items: I
) -> DelayedFormat<I>
Makes a new DelayedFormat value out of local date and time.
pub fn new_with_offset<Off>(
date: Option<NaiveDate>,
time: Option<NaiveTime>,
offset: &Off,
items: I
) -> DelayedFormat<I> where
Off: Offset + Display, [src]
date: Option<NaiveDate>,
time: Option<NaiveTime>,
offset: &Off,
items: I
) -> DelayedFormat<I> where
Off: Offset + Display,
Makes a new DelayedFormat value out of local date and time and UTC offset.