Struct otter_api_tests::imports::glob::MatchOptions [−][src]
pub struct MatchOptions {
pub case_sensitive: bool,
pub require_literal_separator: bool,
pub require_literal_leading_dot: bool,
}Configuration options to modify the behaviour of Pattern::matches_with(..).
Fields
case_sensitive: boolWhether or not patterns should be matched in a case-sensitive manner. This currently only considers upper/lower case relationships between ASCII characters, but in future this might be extended to work with Unicode.
require_literal_separator: boolWhether or not path-component separator characters (e.g. / on
Posix) must be matched by a literal /, rather than by * or ? or
[...].
require_literal_leading_dot: boolWhether or not paths that contain components that start with a .
will require that . appears literally in the pattern; *, ?, **,
or [...] will not match. This is useful because such files are
conventionally considered hidden on Unix systems and it might be
desirable to skip them when listing files.
Implementations
impl MatchOptions[src]
pub fn new() -> MatchOptions[src]
Constructs a new MatchOptions with default field values. This is used
when calling functions that do not take an explicit MatchOptions
parameter.
This function always returns this value:
MatchOptions { case_sensitive: true, require_literal_separator: false, require_literal_leading_dot: false }