Struct otter_api_tests::imports::rmp_serde::config::VariantStringConfig [−]
pub struct VariantStringConfig<C>(_);
Config wrapper, that overrides enum serialization by serializing enum variant names as strings.
Default Serializer implementation writes enum names as integers, i.e. only indices are encoded,
because it is the most compact representation.
Implementations
impl<C> VariantStringConfig<C>
pub fn new(inner: C) -> VariantStringConfig<C>
Creates a VariantStringConfig inheriting unchanged configuration options from the given configuration.