Trait otter_api_tests::str::FromStr 1.0.0[−][src]
Parse a value from a string
FromStr’s from_str method is often used implicitly, through
str’s parse method. See parse’s documentation for examples.
FromStr does not have a lifetime parameter, and so you can only parse types
that do not contain a lifetime parameter themselves. In other words, you can
parse an i32 with FromStr, but not a &i32. You can parse a struct that
contains an i32, but not one that contains an &i32.
Examples
Basic implementation of FromStr on an example Point type:
use std::str::FromStr; use std::num::ParseIntError; #[derive(Debug, PartialEq)] struct Point { x: i32, y: i32 } impl FromStr for Point { type Err = ParseIntError; fn from_str(s: &str) -> Result<Self, Self::Err> { let coords: Vec<&str> = s.trim_matches(|p| p == '(' || p == ')' ) .split(',') .collect(); let x_fromstr = coords[0].parse::<i32>()?; let y_fromstr = coords[1].parse::<i32>()?; Ok(Point { x: x_fromstr, y: y_fromstr }) } } let p = Point::from_str("(1,2)"); assert_eq!(p.unwrap(), Point{ x: 1, y: 2} )
Associated Types
Loading content...Required methods
pub fn from_str(s: &str) -> Result<Self, Self::Err>[src]
Parses a string s to return a value of this type.
If parsing succeeds, return the value inside Ok, otherwise
when the string is ill-formatted return an error specific to the
inside Err. The error type is specific to implementation of the trait.
Examples
Basic usage with i32, a type that implements FromStr:
use std::str::FromStr; let s = "5"; let x = i32::from_str(s).unwrap(); assert_eq!(5, x);
Implementations on Foreign Types
impl FromStr for IpAddr[src]
type Err = AddrParseError
pub fn from_str(s: &str) -> Result<IpAddr, AddrParseError>[src]
impl FromStr for OsString[src]
impl FromStr for SocketAddrV4[src]
type Err = AddrParseError
pub fn from_str(s: &str) -> Result<SocketAddrV4, AddrParseError>[src]
impl FromStr for SocketAddrV6[src]
type Err = AddrParseError
pub fn from_str(s: &str) -> Result<SocketAddrV6, AddrParseError>[src]
impl FromStr for SocketAddr[src]
type Err = AddrParseError
pub fn from_str(s: &str) -> Result<SocketAddr, AddrParseError>[src]
impl FromStr for Ipv6Addr[src]
type Err = AddrParseError
pub fn from_str(s: &str) -> Result<Ipv6Addr, AddrParseError>[src]
impl FromStr for Ipv4Addr[src]
type Err = AddrParseError
pub fn from_str(s: &str) -> Result<Ipv4Addr, AddrParseError>[src]
impl FromStr for f64[src]
type Err = ParseFloatError
pub fn from_str(src: &str) -> Result<f64, ParseFloatError>[src]
Converts a string in base 10 to a float. Accepts an optional decimal exponent.
This function accepts strings such as
- ‘3.14’
- ‘-3.14’
- ‘2.5E10’, or equivalently, ‘2.5e10’
- ‘2.5E-10’
- ‘5.’
- ‘.5’, or, equivalently, ‘0.5’
- ‘inf’, ‘-inf’, ‘NaN’
Leading and trailing whitespace represent an error.
Grammar
All strings that adhere to the following EBNF grammar
will result in an Ok being returned:
Float ::= Sign? ( 'inf' | 'NaN' | Number )
Number ::= ( Digit+ |
Digit+ '.' Digit* |
Digit* '.' Digit+ ) Exp?
Exp ::= [eE] Sign? Digit+
Sign ::= [+-]
Digit ::= [0-9]
Known bugs
In some situations, some strings that should create a valid float instead return an error. See issue #31407 for details.
Arguments
- src - A string
Return value
Err(ParseFloatError) if the string did not represent a valid
number. Otherwise, Ok(n) where n is the floating-point
number represented by src.
impl FromStr for char[src]
impl FromStr for i8[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<i8, ParseIntError>[src]
impl FromStr for u16[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<u16, ParseIntError>[src]
impl FromStr for u64[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<u64, ParseIntError>[src]
impl FromStr for usize[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<usize, ParseIntError>[src]
impl FromStr for bool[src]
type Err = ParseBoolError
pub fn from_str(s: &str) -> Result<bool, ParseBoolError>[src]
Parse a bool from a string.
Yields a Result<bool, ParseBoolError>, because s may or may not
actually be parseable.
Examples
use std::str::FromStr; assert_eq!(FromStr::from_str("true"), Ok(true)); assert_eq!(FromStr::from_str("false"), Ok(false)); assert!(<bool as FromStr>::from_str("not even a boolean").is_err());
Note, in many cases, the .parse() method on str is more proper.
assert_eq!("true".parse(), Ok(true)); assert_eq!("false".parse(), Ok(false)); assert!("not even a boolean".parse::<bool>().is_err());
impl FromStr for i64[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<i64, ParseIntError>[src]
impl FromStr for u8[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<u8, ParseIntError>[src]
impl FromStr for isize[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<isize, ParseIntError>[src]
impl FromStr for f32[src]
type Err = ParseFloatError
pub fn from_str(src: &str) -> Result<f32, ParseFloatError>[src]
Converts a string in base 10 to a float. Accepts an optional decimal exponent.
This function accepts strings such as
- ‘3.14’
- ‘-3.14’
- ‘2.5E10’, or equivalently, ‘2.5e10’
- ‘2.5E-10’
- ‘5.’
- ‘.5’, or, equivalently, ‘0.5’
- ‘inf’, ‘-inf’, ‘NaN’
Leading and trailing whitespace represent an error.
Grammar
All strings that adhere to the following EBNF grammar
will result in an Ok being returned:
Float ::= Sign? ( 'inf' | 'NaN' | Number )
Number ::= ( Digit+ |
Digit+ '.' Digit* |
Digit* '.' Digit+ ) Exp?
Exp ::= [eE] Sign? Digit+
Sign ::= [+-]
Digit ::= [0-9]
Known bugs
In some situations, some strings that should create a valid float instead return an error. See issue #31407 for details.
Arguments
- src - A string
Return value
Err(ParseFloatError) if the string did not represent a valid
number. Otherwise, Ok(n) where n is the floating-point
number represented by src.
impl FromStr for i16[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<i16, ParseIntError>[src]
impl FromStr for u128[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<u128, ParseIntError>[src]
impl FromStr for u32[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<u32, ParseIntError>[src]
impl FromStr for i32[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<i32, ParseIntError>[src]
impl FromStr for i128[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<i128, ParseIntError>[src]
impl FromStr for String[src]
impl FromStr for Duration[src]
impl FromStr for Timestamp[src]
impl FromStr for Color
impl FromStr for Pattern[src]
type Err = PatternError
pub fn from_str(s: &str) -> Result<Pattern, PatternError>[src]
impl FromStr for Url[src]
Parse a string as an URL, without a base URL or encoding override.
type Err = ParseError
pub fn from_str(input: &str) -> Result<Url, ParseError>[src]
impl FromStr for SentenceBreak
impl FromStr for GraphemeClusterBreak
type Err = ()
pub fn from_str(
s: &str
) -> Result<GraphemeClusterBreak, <GraphemeClusterBreak as FromStr>::Err>
s: &str
) -> Result<GraphemeClusterBreak, <GraphemeClusterBreak as FromStr>::Err>
impl FromStr for WordBreak
impl FromStr for AppSettings[src]
type Err = String
pub fn from_str(s: &str) -> Result<AppSettings, <AppSettings as FromStr>::Err>[src]
impl FromStr for Shell[src]
impl FromStr for ArgSettings[src]
type Err = String
pub fn from_str(s: &str) -> Result<ArgSettings, <ArgSettings as FromStr>::Err>[src]
Implementors
impl FromStr for AccountScope[src]
type Err = InvalidScopedName
pub fn from_str(s: &str) -> Result<AccountScope, InvalidScopedName>[src]
impl FromStr for LinkKind[src]
impl FromStr for PresentationLayout[src]
type Err = ParseError
pub fn from_str(
s: &str
) -> Result<PresentationLayout, <PresentationLayout as FromStr>::Err>[src]
s: &str
) -> Result<PresentationLayout, <PresentationLayout as FromStr>::Err>
impl FromStr for Level[src]
type Err = ParseLevelError
pub fn from_str(level: &str) -> Result<Level, <Level as FromStr>::Err>[src]
impl FromStr for LevelFilter[src]
type Err = ParseLevelError
pub fn from_str(
level: &str
) -> Result<LevelFilter, <LevelFilter as FromStr>::Err>[src]
level: &str
) -> Result<LevelFilter, <LevelFilter as FromStr>::Err>
impl FromStr for Month[src]
Parsing a str into a Month uses the format %W.
Example
use chrono::Month; assert_eq!("January".parse::<Month>(), Ok(Month::January)); assert!("any day".parse::<Month>().is_err());
The parsing is case-insensitive.
assert_eq!("fEbruARy".parse::<Month>(), Ok(Month::February));
Only the shortest form (e.g. jan) and the longest form (e.g. january) is accepted.
assert!("septem".parse::<Month>().is_err()); assert!("Augustin".parse::<Month>().is_err());
impl FromStr for Weekday[src]
Parsing a str into a Weekday uses the format %W.
Example
use chrono::Weekday; assert_eq!("Sunday".parse::<Weekday>(), Ok(Weekday::Sun)); assert!("any day".parse::<Weekday>().is_err());
The parsing is case-insensitive.
assert_eq!("mON".parse::<Weekday>(), Ok(Weekday::Mon));
Only the shortest form (e.g. sun) and the longest form (e.g. sunday) is accepted.
assert!("thurs".parse::<Weekday>().is_err());
type Err = ParseWeekdayError
pub fn from_str(s: &str) -> Result<Weekday, <Weekday as FromStr>::Err>[src]
impl FromStr for Tz
impl FromStr for Signal
impl FromStr for otter_api_tests::imports::toml::Value[src]
impl FromStr for otter_api_tests::serde_json::Value[src]
impl FromStr for DateTime<FixedOffset>[src]
type Err = ParseError
pub fn from_str(s: &str) -> Result<DateTime<FixedOffset>, ParseError>[src]
impl FromStr for DateTime<Local>[src]
type Err = ParseError
pub fn from_str(s: &str) -> Result<DateTime<Local>, ParseError>[src]
impl FromStr for DateTime<Utc>[src]
type Err = ParseError
pub fn from_str(s: &str) -> Result<DateTime<Utc>, ParseError>[src]
impl FromStr for NaiveDate[src]
Parsing a str into a NaiveDate uses the same format,
%Y-%m-%d, as in Debug and Display.
Example
use chrono::NaiveDate; let d = NaiveDate::from_ymd(2015, 9, 18); assert_eq!("2015-09-18".parse::<NaiveDate>(), Ok(d)); let d = NaiveDate::from_ymd(12345, 6, 7); assert_eq!("+12345-6-7".parse::<NaiveDate>(), Ok(d)); assert!("foo".parse::<NaiveDate>().is_err());
type Err = ParseError
pub fn from_str(s: &str) -> Result<NaiveDate, ParseError>[src]
impl FromStr for NaiveDateTime[src]
Parsing a str into a NaiveDateTime uses the same format,
%Y-%m-%dT%H:%M:%S%.f, as in Debug.
Example
use chrono::{NaiveDateTime, NaiveDate}; let dt = NaiveDate::from_ymd(2015, 9, 18).and_hms(23, 56, 4); assert_eq!("2015-09-18T23:56:04".parse::<NaiveDateTime>(), Ok(dt)); let dt = NaiveDate::from_ymd(12345, 6, 7).and_hms_milli(7, 59, 59, 1_500); // leap second assert_eq!("+12345-6-7T7:59:60.5".parse::<NaiveDateTime>(), Ok(dt)); assert!("foo".parse::<NaiveDateTime>().is_err());
type Err = ParseError
pub fn from_str(s: &str) -> Result<NaiveDateTime, ParseError>[src]
impl FromStr for NaiveTime[src]
Parsing a str into a NaiveTime uses the same format,
%H:%M:%S%.f, as in Debug and Display.
Example
use chrono::NaiveTime; let t = NaiveTime::from_hms(23, 56, 4); assert_eq!("23:56:04".parse::<NaiveTime>(), Ok(t)); let t = NaiveTime::from_hms_nano(23, 56, 4, 12_345_678); assert_eq!("23:56:4.012345678".parse::<NaiveTime>(), Ok(t)); let t = NaiveTime::from_hms_nano(23, 59, 59, 1_234_567_890); // leap second assert_eq!("23:59:60.23456789".parse::<NaiveTime>(), Ok(t)); assert!("foo".parse::<NaiveTime>().is_err());
type Err = ParseError
pub fn from_str(s: &str) -> Result<NaiveTime, ParseError>[src]
impl FromStr for NonZeroI81.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroI8, <NonZeroI8 as FromStr>::Err>[src]
impl FromStr for NonZeroI161.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroI16, <NonZeroI16 as FromStr>::Err>[src]
impl FromStr for NonZeroI321.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroI32, <NonZeroI32 as FromStr>::Err>[src]
impl FromStr for NonZeroI641.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroI64, <NonZeroI64 as FromStr>::Err>[src]
impl FromStr for NonZeroI1281.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroI128, <NonZeroI128 as FromStr>::Err>[src]
impl FromStr for NonZeroIsize1.35.0[src]
type Err = ParseIntError
pub fn from_str(
src: &str
) -> Result<NonZeroIsize, <NonZeroIsize as FromStr>::Err>[src]
src: &str
) -> Result<NonZeroIsize, <NonZeroIsize as FromStr>::Err>
impl FromStr for NonZeroU81.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroU8, <NonZeroU8 as FromStr>::Err>[src]
impl FromStr for NonZeroU161.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroU16, <NonZeroU16 as FromStr>::Err>[src]
impl FromStr for NonZeroU321.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroU32, <NonZeroU32 as FromStr>::Err>[src]
impl FromStr for NonZeroU641.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroU64, <NonZeroU64 as FromStr>::Err>[src]
impl FromStr for NonZeroU1281.35.0[src]
type Err = ParseIntError
pub fn from_str(src: &str) -> Result<NonZeroU128, <NonZeroU128 as FromStr>::Err>[src]
impl FromStr for otter_api_tests::imports::glob::Pattern[src]
type Err = PatternError
pub fn from_str(s: &str) -> Result<Pattern, PatternError>[src]
impl FromStr for otter_api_tests::imports::regex::bytes::Regex
type Err = Error
pub fn from_str(s: &str) -> Result<Regex, Error>
Attempts to parse a string into a regular expression
impl FromStr for Datetime[src]
type Err = DatetimeParseError
pub fn from_str(date: &str) -> Result<Datetime, DatetimeParseError>[src]
impl FromStr for Number[src]
impl FromStr for NonZeroUsize1.35.0[src]
type Err = ParseIntError
pub fn from_str(
src: &str
) -> Result<NonZeroUsize, <NonZeroUsize as FromStr>::Err>[src]
src: &str
) -> Result<NonZeroUsize, <NonZeroUsize as FromStr>::Err>
impl FromStr for PathBuf1.32.0[src]
impl FromStr for otter_api_tests::shapelib::Regex
type Err = Error
pub fn from_str(s: &str) -> Result<Regex, Error>
Attempts to parse a string into a regular expression
impl FromStr for otter_api_tests::shapelib::Url[src]
Parse a string as an URL, without a base URL or encoding override.
type Err = ParseError
pub fn from_str(input: &str) -> Result<Url, ParseError>[src]
impl FromStr for ZCoord
type Err = ParseError
pub fn from_str(s: &str) -> Result<ZCoord, ParseError>
impl FromStr for AbbrevPresentationLayout[src]
type Err = ()
pub fn from_str(
s: &str
) -> Result<AbbrevPresentationLayout, <AbbrevPresentationLayout as FromStr>::Err>[src]
s: &str
) -> Result<AbbrevPresentationLayout, <AbbrevPresentationLayout as FromStr>::Err>
impl FromStr for AccountName[src]
type Err = InvalidScopedName
pub fn from_str(s: &str) -> Result<AccountName, InvalidScopedName>[src]
impl FromStr for InstanceName[src]
type Err = InvalidScopedName
pub fn from_str(s: &str) -> Result<InstanceName, InvalidScopedName>[src]
impl FromStr for Timezone[src]
impl<A> FromStr for ArrayString<A> where
A: Array<Item = u8> + Copy, [src]
A: Array<Item = u8> + Copy,
type Err = CapacityError<()>
pub fn from_str(
s: &str
) -> Result<ArrayString<A>, <ArrayString<A> as FromStr>::Err>[src]
s: &str
) -> Result<ArrayString<A>, <ArrayString<A> as FromStr>::Err>
impl<T> FromStr for NotNan<T> where
T: Float + FromStr,
T: Float + FromStr,
type Err = ParseNotNanError<<T as FromStr>::Err>
pub fn from_str(src: &str) -> Result<NotNan<T>, <NotNan<T> as FromStr>::Err>
Convert a &str to NotNan. Returns an error if the string fails to parse,
or if the resulting value is NaN
use ordered_float::NotNan; assert!("-10".parse::<NotNan<f32>>().is_ok()); assert!("abc".parse::<NotNan<f32>>().is_err()); assert!("NaN".parse::<NotNan<f32>>().is_err());
impl<T> FromStr for OrderedFloat<T> where
T: FromStr,
T: FromStr,
type Err = <T as FromStr>::Err
pub fn from_str(
s: &str
) -> Result<OrderedFloat<T>, <OrderedFloat<T> as FromStr>::Err>
s: &str
) -> Result<OrderedFloat<T>, <OrderedFloat<T> as FromStr>::Err>
Convert a &str to OrderedFloat. Returns an error if the string fails to parse.
use ordered_float::OrderedFloat; assert!("-10".parse::<OrderedFloat<f32>>().is_ok()); assert!("abc".parse::<OrderedFloat<f32>>().is_err()); assert!("NaN".parse::<OrderedFloat<f32>>().is_ok());