pub type LOI = LOccultIlk;Aliased Type
pub enum LOI {
Distinct,
Mix(GoodItemName),
}Variants
Distinct
Pieces does not participate in ilk-based mixing.
Such a piece remains distinguishable from all other pieces, and trackable, by all players, even when occulted (unless made totally invisible, in which case it will still be trackable when it returns).
Mix(GoodItemName)
Ilk-based mixing
Pieces with the same OccultIlkName will be mixed together when occulted, so that players who see the occulted view cannot track the individual piece identities. This supports deck-shuffling for pickup decks (and for hands etc. hides what the player is doing with their own cards, from the other players).