pub type WRC = WhatResponseToClientOp;Aliased Type
pub enum WRC {
Predictable,
UpdateSvg,
Unpredictable,
}Variants
Predictable
In PROTOCOL.md terms, a Client update
UpdateSvg
In PROTOCOL.md terms, a Client update which also updates the visible piece image (which is just server-controlled).
Unpredictable
In PROTOCOL.md terms, a Client update which results in an immediate Server update. When the client knows this is going to happen it can help the user avoid conflicts.